SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[CreateVcc] (
	@VCC Varchar(50) = NULL, 
	@ID Varchar(50) = NULL,
	@Description Varchar(50) = NULL,
	@Type VARCHAR(50) = NULL,
	@TranscriptionDefaultLanguage VARCHAR(25) = NULL,
	@CognitiveEngine VARCHAR(25) = NULL,
	@Country Varchar(50) = NULL,
	@Language Varchar(50) = NULL,
	@TimeZone Varchar(50) = NULL,
	@CreatedDate Datetime = NULL,
	@CreatedByUserId Varchar(50) = NULL,
	@LastModifiedDate Datetime = NULL,
	@LastModifiedByUserId   VARCHAR(50) = NULL,
	@DeleteDataDays         INT = 360
	)
AS
BEGIN
	SET NOCOUNT ON
	BEGIN TRY
    BEGIN TRANSACTION


	INSERT INTO [dbo].[VCC] (
			[VCC], 
			[ID], 
			[Description], 
			[Type], 
			[Country], 
			[TranscriptionDefaultLanguage], 
			[CognitiveEngine], 
			[Language],
			[TimeZone], 
			[CreatedDate], 
			[CreatedByUserId], 
			[LastModifiedDate], 
			[LastModifiedByUserId], 
			[DeleteDataDays], 
			[TimeStamp]
			)
	VALUES (
			@VCC, 
			@ID, 
			@Description, 
			@Type, 
			@Country, 
			@TranscriptionDefaultLanguage, 
			@CognitiveEngine, 
			@Language, 
			@TimeZone, 
			@CreatedDate,  
			@CreatedByUserId, 
			@LastModifiedDate, 
			@LastModifiedByUserId, 
			@DeleteDataDays,
			GETUTCDATE()
		)
	
	DECLARE @VCC_SYSTEM       VARCHAR(50) = 'system'

    --INSERTAR ROLES
	
	DECLARE @ROLES TABLE(
    [ID]            VARCHAR(50),
    [Description]   VARCHAR(50),
	[CreatedDate]   DATETIME,
    [CreatedByUserId] VARCHAR(50),
    [LastModifiedDate] DATETIME,
    [LastModifiedByUserId] VARCHAR(50),
	[SystemRole]    BIT,
    [Type]                 VARCHAR(50)
	)
	INSERT INTO @ROLES EXEC [dbo].[GetRoles] @VCC_SYSTEM,'name',''

	IF(EXISTS(SELECT [ID] FROM @ROLES))
	BEGIN
			INSERT INTO [dbo].[Role] (
					[VCC],
					[ID], 
					[Description],
					[CreatedDate], 
					[CreatedByUserId], 
					[LastModifiedDate],
					[LastModifiedByUserId],
					[SystemRole],
					[Type],
					[TimeStamp]
					)
			SELECT @VCC,
				   [ID],
				   [Description],
				   GETUTCDATE(), 
				   [CreatedByUserId],
				   GETUTCDATE(),
				   [LastModifiedByUserId],
				   [SystemRole],
				   [Type],
				   GETUTCDATE()
			FROM @ROLES
     END
	 ELSE
	 BEGIN
	       RAISERROR('SERVER_ERROR_ROLES_NOT_FOUND', 16, 16)
	 END

	--INSERTAR PERMISOS PARA LOS ROLES

	DECLARE @CountLicense INT = 0
	DECLARE @License      VARCHAR(50)
	
	DECLARE @ROLE_PERMISSIONS TABLE(
	 [ID]      VARCHAR(50),
	 [GroupId] VARCHAR(200)
	)
	DECLARE @ROUTE_PERMISSIONS TABLE(
	 [ID]      VARCHAR(50),
	 [Route]   VARCHAR(250),
	 [Level]   VARCHAR(50),
	 [GroupId] VARCHAR(200)
	)

	SET @CountLicense = (SELECT COUNT(*) FROM [dbo].[VCCLicense] (NOLOCK) WHERE [VCC] = @VCC AND [Status] = 1)
	
	IF(@CountLicense>1)
	BEGIN
	    INSERT INTO @ROLE_PERMISSIONS EXEC [dbo].[GetRolePermission] @VCC_SYSTEM,''
		INSERT INTO @ROUTE_PERMISSIONS EXEC [dbo].[GetRoleRoutePermission] @VCC_SYSTEM
	END

	IF(@CountLicense=1)
	BEGIN
	    SET @License = (SELECT Product FROM [dbo].[VCCLicense] (NOLOCK) WHERE [VCC] = @VCC AND [Status] = 1)
	    INSERT INTO @ROLE_PERMISSIONS EXEC [dbo].[GetRolePermission] @VCC_SYSTEM,'', @License
		INSERT INTO @ROUTE_PERMISSIONS EXEC [dbo].[GetRoleRoutePermission] @VCC_SYSTEM,'', @License
	END
	
	INSERT INTO [dbo].[RolePermission] (
			    [VCC], 
				[RoleId], 
				[GroupId],
			    [TimeStamp]
			    ) 
				SELECT 
				@VCC,
				[ID],
				[GroupId],
			    GETUTCDATE()
				FROM @ROLE_PERMISSIONS

	INSERT INTO [dbo].[RoutePermission] (
			[VCC], 
			[ID], 
			[GroupId],
			[Route], 
			[Level], 
			[TimeStamp]
			)
			SELECT 
			@VCC,
			[ID],
			[GroupId],
			[Route],
			[Level],
			GETUTCDATE()
			FROM @ROUTE_PERMISSIONS


    --INSERTAR GRUPOS DE PERMISOS PARA LOS ROLES
	DECLARE @ROLE_PERMISSIONS_GROUP TABLE(
	 [Category] VARCHAR(50),
	 [GroupId]  VARCHAR(200),
	 [Type]     VARCHAR(50)
	)

	INSERT INTO @ROLE_PERMISSIONS_GROUP EXEC [dbo].[GetRolePermissionsGroups] @VCC_SYSTEM

	INSERT INTO [dbo].[RolePermissionsGroup] (
			                              [VCC], 
										  [GroupId], 
										  [Category], 
										  [Type], 
										  [TimeStamp]
										  )
		                                 SELECT 
										 @VCC, 
										 GroupId,
										 Category,
										 [Type], 
										 GETUTCDATE()	
										 FROM @ROLE_PERMISSIONS_GROUP

    --INSERTAR FEELINGS
	INSERT INTO [dbo].[Feeling] (
			                   [VCC], 
							   [Name], 
							   [Description],
							   [CreatedDate], 
							   [CreatedByUserId], 
							   [LastModifiedDate], 
							   [LastModifiedByUserId], 
							   [TimeStamp]
							   )
							   SELECT
							   @VCC,
							   [Name],
							   [Description],
							   GETUTCDATE(),
							   [CreatedByUserId],
							   GETUTCDATE(),
							   [LastModifiedByUserId],
							   GETUTCDATE()	
							   FROM [dbo].[Feeling] (NOLOCK)
							   WHERE [VCC] = @VCC_SYSTEM

    --INSERTAR PROGRAMACION NEUROLINGUISTICA
	INSERT INTO [dbo].[NeuroLinguisticProgramming] (
								[VCC],
								[Name],
								[Description],
								[CreatedDate],
								[CreatedByUserId],
								[LastModifiedDate], 
								[LastModifiedByUserId],
								[TimeStamp]
								)
								SELECT 
								@VCC,
								[Name],
								[Description],
								GETUTCDATE(),
								[CreatedByUserId],
								GETUTCDATE(),
								[LastModifiedByUserId],
								GETUTCDATE()
								FROM [dbo].[NeuroLinguisticProgramming] (NOLOCK)
								WHERE [VCC] = @VCC_SYSTEM
		
   --INSERTAR PALABRAS
   IF(EXISTS(SELECT [Name] FROM [dbo].[Word] (NOLOCK) WHERE [VCC] = @VCC_SYSTEM))
   BEGIN
		   INSERT INTO [dbo].[Word](
					[VCC],
					[NeuroLinguisticProgrammingId],
					[Name],
					[ProcessId],
					[Language],
					[Type],
					[CreatedDate],
					[CreatedByUserId],
					[LastModifiedDate],
					[LastModifiedByUserId],
					[TimeStamp]
					)
				SELECT
				@VCC,
				[NeuroLinguisticProgrammingId],
				[Name],
				[ProcessId],
				[Language],
				[Type],
				GETUTCDATE(),
				[CreatedByUserId],
				GETUTCDATE(),
				[LastModifiedByUserId],
				GETUTCDATE()
			   FROM [dbo].[Word] (NOLOCK)
			   WHERE [VCC] = @VCC_SYSTEM
   END
   ELSE
   BEGIN
	       RAISERROR('SERVER_ERROR_WORD_NOT_FOUND', 16, 16)
   END

   --INSERTAR CATEGORIAS
   INSERT INTO [dbo].[Category] (
			[VCC], 
			[Name], 
			[Description],
			[CreatedDate], 
			[CreatedByUserId], 
			[LastModifiedDate], 
			[LastModifiedByUserId], 
			[TimeStamp]
			)
		SELECT 
		@VCC,
		[Name],
		[Description],
		GETUTCDATE(),
		[CreatedByUserId],
		GETUTCDATE(),
		[LastModifiedByUserId],
		GETUTCDATE()
	FROM [dbo].[Category] (NOLOCK)
	WHERE [VCC] = @VCC_SYSTEM

	--INSERTAR AMBIENTES
	IF(@Type <> 'OTHER')
	BEGIN
		DECLARE @NAME VARCHAR(100)
		SELECT @NAME = [Word] FROM [dbo].[WordsByLanguage] (NOLOCK) WHERE [Language] = @Language AND [Label] = 'ENVIRONMENT' 
		
		-- DECLARAMOS UNA VARIABLE PARA SETTEAR EL TIPO DE AMBIENTE INTEGRADO PARA EL VCC
		DECLARE @VCC_TYPE VARCHAR(25) = NULL
		IF (@Type = 'ALLEGRO' OR @Type = 'OCC') SET @VCC_TYPE = 'allegro'
		ELSE IF @Type = 'I6' SET @VCC_TYPE = 'i6'
		
		INSERT INTO [dbo].[Environment] (
			[VCC], 
			[Name], 
			[Type],
			[Description],
			[FTPDirectory],
			[ApiHost],
			[ApiPort],
			[ApiUser],
			[DbDisabled],
			[DbServer],
			[DbPort],
			[DbUser], 
			[PbxDisabled],
			[PbxServer],
			[PbxPort],
			[PbxUser],
			[ApiPassword],
			[DbPassword],
			[PbxPassword],
			[CreatedDate],
			[CreatedByUserId],
			[TimeStamp]
		)
			SELECT @VCC,
					@NAME,
					[Type],
					@NAME,
					[FTPDirectory],
					[ApiHost],
					[ApiPort],
					[ApiUser],
					[DbDisabled],
					[DbServer],
					[DbPort],
					[DbUser],
					[PbxDisabled],
					[PbxServer]	,
					[PbxPort],
					[PbxUser],
					[ApiPassword],
					[DbPassword],
					[PbxPassword],
					GETUTCDATE(),
					[CreatedByUserId],
					GETUTCDATE()
				FROM [dbo].[Environment] (NOLOCK)
				WHERE [VCC] = @VCC_SYSTEM
					AND [Type] = @VCC_TYPE

	END


	--INSERTAR PERMISOS PARA CATEGORIAS
	INSERT INTO [dbo].[CategoryPermissions](
			[VCC], 
			[Category], 
			[Position], 
			[TimeStamp]
			)
			SELECT
			@VCC,
		    [Category],
			[Position],
			GETUTCDATE()
			FROM [dbo].[CategoryPermissions] (NOLOCK) 
			WHERE [VCC] = @VCC_SYSTEM
			GROUP BY [Category],[Position]
		  

   --INSERTAR TENANT
   DECLARE @TENANT TABLE(
    [TenantId]     VARCHAR(50),
    [ClientId]     VARCHAR(50),
    [ClientSecret] VARCHAR(50),
    [Resource]     VARCHAR(50)
	)
	
	INSERT INTO @TENANT EXEC [dbo].[GetTenantVCCByVCC] @VCC_SYSTEM
	IF(EXISTS(SELECT [TenantId] FROM @TENANT))
	BEGIN

		INSERT INTO [dbo].[TenantVCC](
		[VCC], 
		[TenantId], 
		[ClientId], 
		[ClientSecret], 
		[Resource], 
		[CreatedDate], 
		[CreatedByUserId], 
		[TimeStamp])
		SELECT 
		@VCC,
		[TenantId],
		[ClientId],
		[ClientSecret],
		[Resource],
		GETUTCDATE(),
		@CreatedByUserId,
		GETUTCDATE()
		FROM @TENANT

	END
	ELSE
	BEGIN
	   RAISERROR('SERVER_ERROR_TENANT_NOT_FOUND', 16, 16)
	END

	--INSERTAR NLU
	IF(EXISTS(SELECT [Name] FROM [dbo].[NLU] WHERE [IsSystemApp]=1 AND [VCC] = @VCC_SYSTEM))
	BEGIN
		INSERT INTO [dbo].[NLU] (
					[VCC], 
					[Name], 
					[Culture],
					[Description], 
					[AppId], 
					[NeedTrain],
					[SubscriptionKey],
					[IsSystemApp], 
					[CreatedDate], 
					[CreatedByUserId], 
					[LastModifiedDate], 
					[LastModifiedByUserId], 
					[TimeStamp],
					[CognitiveEngine]
					)
					SELECT
					@VCC,
					[Name], 
					[Culture],
					[Description], 
					CONCAT(@VCC,'::',[Name]), 
					CASE WHEN [Name] LIKE 'sentiment_%'  THEN 1 ELSE 0 END,
					[SubscriptionKey],
					[IsSystemApp], 
					GETUTCDATE(), 
					[CreatedByUserId], 
					GETUTCDATE(), 
					[LastModifiedByUserId], 
					GETUTCDATE(),
					'RASA'
					FROM [dbo].[NLU]
					WHERE [IsSystemApp]=1 AND [VCC] = @VCC_SYSTEM 

		-- INSERTAMOS LOS REGISTROS DE MODELOS DE DIARIZACION
        INSERT INTO [dbo].[Intent](
			[VCC], 
			[Name],
			[IntentId],
			[AppId],
			[CreatedDate],
			[CreatedByUserId],
			[LastModifiedDate], 
			[LastModifiedByUserId], 
			[TimeStamp],
			[Status],
			[StatusCode]
		)
			SELECT @VCC,
					'Agent',
					'Agent',
					CONCAT(@VCC,'::',[Name]),
					GETUTCDATE(),
					@CreatedByUserId,
					GETUTCDATE(),
					@CreatedByUserId,
					GETUTCDATE(),
					1,
					'AVAILABLE'
			FROM [dbo].[NLU]
			WHERE [IsSystemApp]=1 
				AND [VCC] = @VCC_SYSTEM
				AND [Name] LIKE 'diarization-%'


		-- TODO: CORREGIR PARA REDUCIR 3 INSERT REEMPLAZANDO POR 1 SOLO --
		INSERT INTO [dbo].[Intent](
			[VCC], 
			[Name],
			[IntentId],
			[AppId],
			[Color],
			[CreatedDate],
			[CreatedByUserId],
			[LastModifiedDate], 
			[LastModifiedByUserId], 
			[TimeStamp],
			[Status],
			[StatusCode]
		)
			SELECT @VCC,
					'Positive',
					'Positive',
					CONCAT(@VCC,'::',[Name]),
					'far fa-smile',
					GETUTCDATE(),
					@CreatedByUserId,
					GETUTCDATE(),
					@CreatedByUserId,
					GETUTCDATE(),
					1,
					'AVAILABLE'
			FROM [dbo].[NLU]
			WHERE [IsSystemApp]=1 
				AND [VCC] = @VCC_SYSTEM 
				AND [Name] LIKE 'sentiment-%'
		 
		INSERT INTO [dbo].[Intent](
			[VCC], 
			[Name],
			[IntentId],
			[AppId],
			[Color],
			[CreatedDate],
			[CreatedByUserId],
			[LastModifiedDate], 
			[LastModifiedByUserId], 
			[TimeStamp],
			[Status],
			[StatusCode]
		)
			SELECT @VCC,
					'Negative',
					'Negative',
					CONCAT(@VCC,'::',[Name]),
					'far fa-frown',
					GETUTCDATE(),
					@CreatedByUserId,
					GETUTCDATE(),
					@CreatedByUserId,
					GETUTCDATE(),
					1,
					'AVAILABLE'
				FROM [dbo].[NLU]
				WHERE [IsSystemApp]=1 
					AND [VCC] = @VCC_SYSTEM 
					AND [Name] LIKE 'sentiment-%'
		
		 INSERT INTO [dbo].[Intent] (
			[VCC], 
			[Name],
			[IntentId],
			[AppId],
			[Color],
			[CreatedDate],
			[CreatedByUserId],
			[LastModifiedDate], 
			[LastModifiedByUserId], 
			[TimeStamp],
			[Status],
			[StatusCode]
		)
			SELECT @VCC,
					'Neutral',
					'Neutral',
					CONCAT(@VCC,'::',[Name]),
					'far fa-meh',
					GETUTCDATE(),
					@CreatedByUserId,
					GETUTCDATE(),
					@CreatedByUserId,
					GETUTCDATE(),
					1,
					'AVAILABLE'
				FROM [dbo].[NLU]
				WHERE [IsSystemApp]=1 
					AND [VCC] = @VCC_SYSTEM 
					AND [Name] LIKE 'sentiment-%'
			
			--AGREGAMOS UTTERANCES PARA SENTIMIENTOS.

			INSERT INTO [dbo].[Utterance]( 
			[VCC], 
			[AppId], 
			[IntentId], 
			[Id], 
			[Text], 
			[CreatedDate], 
			[CreatedByUserId], 
			[LastModifiedDate],
			[LastModifiedByUserId], 
			[Status],
			[StatusCode]
			) 
			SELECT @VCC,
			REPLACE(appId,'system',@VCC),
			[IntentId],
			NEWID(),
			[Text],
			GETUTCDATE(),
			'system',
			null,
			null,
			[Status],
			[StatusCode] 
			FROM [dbo].[Utterance]
			WHERE [VCC] =  @VCC_SYSTEM  AND [AppId] LIKE '%sentiment-%'


		-- TODO: CORREGIR PARA REDUCIR 3 INSERT REEMPLAZANDO POR 1 SOLO --
	END
	ELSE
	BEGIN
	   RAISERROR('SERVER_ERROR_SYSTEM_APPS_SAVING_FAILED', 16, 16)
	END

	--INSERTAR DICCIONARIOS
	IF(EXISTS(SELECT [Name] FROM [dbo].[Dictionary] (NOLOCK) WHERE [VCC] = @VCC_SYSTEM))
	BEGIN 
	INSERT INTO [dbo].[Dictionary] (
			[VCC], 
			[Name], 
			[Description], 
			[Language], 
			[IsSystemDictionary], 
			[CreatedDate], 
			[CreatedByUserId], 
			[TimeStamp]
		)
		SELECT
		    @VCC,
		    [Name],
			[Description],
			[Language],
			[IsSystemDictionary],
			GETUTCDATE(),
			[CreatedByUserId],
			GETUTCDATE()
		FROM [dbo].[Dictionary] (NOLOCK)
		WHERE [VCC] = @VCC_SYSTEM
	END
	ELSE
	BEGIN
	    RAISERROR('SERVER_ERROR_SYSTEM_DICTIONARIES_SAVING_FAILED',16,16)
	END

	--INSERTAR TIPOS DE INTERACCIONES
	IF(EXISTS(SELECT [ID] FROM [dbo].[InteractionType] WHERE [Instance] = @VCC_SYSTEM ))
	BEGIN
	INSERT INTO [dbo].[InteractionType] (
			[Instance],
			[ID],
			[Description]
			)
			SELECT
			@VCC,
			[ID],
		    [Description]
			FROM InteractionType  (NOLOCK)
			WHERE [Instance] = @VCC_SYSTEM
	END
	ELSE
	BEGIN
	   RAISERROR('SERVER_ERROR_INTERACTION_TYPE_NOT_FOUND',16,16) 
	END

	--INSERTAR GENERIC QUERY
	IF(EXISTS(SELECT [Name] FROM [dbo].[GenericQuery] (NOLOCK) WHERE [VCC] = @VCC_SYSTEM))
	BEGIN
	INSERT INTO [dbo].[GenericQuery]
		(
			[VCC],
			[Name],
			[Description],
			[Query],
			[RawData],
			[CreatedDate],
			[CreatedByUserId],
			[LastModifiedDate], 
			[LastModifiedByUserId],
			[Version],
			[TimeStamp]
		)
		SELECT
		@VCC,
		[Name],--REPLACE([Name], @Language+'_', ''),
		[Description],
		[Query],
		[RawData],
		GETUTCDATE(),
		[CreatedByUserId],
		GETUTCDATE(),
		[LastModifiedByUserId],
		[Version],
		GETUTCDATE()
		FROM [dbo].[GenericQuery] (NOLOCK)
		WHERE [VCC] = @VCC_SYSTEM --AND [Name] LIKE @Language + '%'
	END
	ELSE
	BEGIN
	   RAISERROR('SERVER_ERROR_GENERIC_QUERY_NOT_FOUND',16,16) 
	END

	--INSERTAR  USUARIO AUDITOR SPEECH
	EXEC [dbo].[SaveSpeechAnalyticAuditorUser] @VCC

	--INSERTAR REPORTES
	IF(EXISTS(SELECT [ID] FROM  [dbo].[Report] (NOLOCK) WHERE [VCC] = @VCC_SYSTEM))
	BEGIN
	INSERT INTO [Report] (
			[VCC], 
			[ID], 
			[Description],
			[Type],
            [Procedure], 
			[StartDate],
			[EndDate],
            [Frecuency],
			[HourSpace],
			[ExactTime],
            [Weekday],
			[DayMonth],
			[Summary],
            [Filter], 
			[Email], 
			[CreatedDate],
            [CreatedByUserId],
			[LastModifiedDate],
			[LastModifiedByUserId],
            [TimeStamp]
        )
		SELECT
		        @VCC,
				[ID],
				[Description],
				[Type],
				[Procedure],
				[StartDate],
				[EndDate],
				[Frecuency],
				[HourSpace],
				[ExactTime],
				[Weekday],
				[DayMonth],
				[Summary],
				[Filter],
				[Email],
				GETUTCDATE(),
				@CreatedByUserId,
				GETUTCDATE(),
				@CreatedByUserId,
				GETUTCDATE()
			FROM [dbo].[Report] (NOLOCK)
			WHERE [VCC] = @VCC_SYSTEM

	END
	ELSE
	BEGIN
	   RAISERROR('SERVER_ERROR_REPORT_NOT_FOUND',16,16) 
	END

		-- INSERTAMOS LOS GRUPOS POR DEFECTO PARA COPC
		INSERT INTO [dbo].[Group] ([Instance], [ID], [Description], [CreatedDate], [CreatedByUserId], [TimeStamp], [Enabled])
			SELECT @VCC,
					G.[Description],
					WBL.[Word],
					GETUTCDATE(),
					'system',
					GETUTCDATE(),
					1
				FROM [dbo].[Group] G (NOLOCK)
				INNER JOIN [dbo].[WordsByLanguage] WBL (NOLOCK)
					ON WBL.[Label] = G.[Description]
				WHERE G.[Instance] = @VCC_SYSTEM
					AND WBL.[Language] = @Language

		-- INSERTAMOS LOS SUBGRUPOS POR DEFECTO PARA COPC
		INSERT INTO [dbo].[SubGroup] ([Instance], [ID], [Description], [CreatedDate], [CreatedByUserId], [TimeStamp], [Enabled])
			SELECT @VCC,
					SG.[Description],
					WBL.[Word],
					GETUTCDATE(),
					'system',
					GETUTCDATE(),
					1
				FROM [dbo].[SubGroup] SG (NOLOCK)
				INNER JOIN [dbo].[WordsByLanguage] WBL (NOLOCK)
					ON WBL.[Label] = SG.[Description]
				WHERE SG.[Instance] = @VCC_SYSTEM
					AND WBL.[Language] = @Language

	COMMIT TRANSACTION

    END TRY

    BEGIN CATCH

    IF @@TRANCOUNT > 0 
	BEGIN
		ROLLBACK TRANSACTION
		--ELIMINAR LOS REGISTROS SI HA FALLADO
		EXEC [dbo].[RollbackVcc] @VCC
	END

    DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
    DECLARE @Severity integer = ERROR_SEVERITY()
    DECLARE @State integer = ERROR_STATE()

    RAISERROR(@Message, @Severity, @State)
  
    END CATCH
    SET NOCOUNT OFF
END

GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
