SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetAllegroInteractions] (
	@Ip						VARCHAR(50),
	@VCC					VARCHAR(50),
	@StartDate				DATETIME = NULL,
	@EndDate				DATETIME = NULL,
	@StartHour				VARCHAR(50),
	@EndHour				VARCHAR(50),
	@Campaign				VARCHAR(MAX),
	@Agent					VARCHAR(MAX),
	@ResultCode				VARCHAR(MAX),
	@Type					INT,
	@Origin					VARCHAR(MAX),
	@MinDuration			INT,
	@MaxDuration			INT,
	@Format					VARCHAR(50) = NULL, 
	@InteractionIds         VARCHAR(MAX) = NULL, 
	@Evaluated              VARCHAR(MAX) = NULL,
	-- @UniqueIds				BIT = 0,							-- ESTE FLAG TIENE COMO PROPOSITO RETORNAR LA LISTA CONSOLIDAD POR IDS O EL TOTAL DEL LISTADO (AUDIOS/INTERACTIONS)
	@ResultType				VARCHAR(50) = NULL,						-- VARIABLE PARA DETERMINAR SI LA BUSQUEDA SERA SOBRE SOBRE DETALLES O ID (DETAILED, SUMMARIZED)
	@ContactAddress			VARCHAR(300) = NULL
) AS
BEGIN
	-- SETTEAMOS UN VALOR POR DEFECTO AL FORMAT
	IF @Format IS NULL OR @Format = '' SET @Format = 'mp3,wav'

	-- SETTEAMOS VALORES MINIMOS PARA LAS HORAS DE INICIO Y FIN
	IF (@StartHour IS NOT NULL AND @StartHour = '') SET @StartHour = '00:00:00'
	IF (@EndHour IS NOT NULL AND @EndHour = '') SET @EndHour = '23:59:59'

	-- DECLARAMOS UNA VARIABLE PARA IDENTIFICAR SI EL SP ES LLAMADO DEL SISTEMA O POR OTRO SP
	DECLARE @IS_NESTED BIT = 0

	-- CREAMOS LAS VARIABLES QUE HARAN REFERENCIA A LAS TABLAS QUE PUEDEN SER EXTERNAS
	DECLARE @TABLE_HISTORICAL_DATA VARCHAR(50) = ''
	DECLARE @TABLE_MMPRODAT VARCHAR(50) = ''

	-- DECLARAMOS CADENAS PARA EL QUERY FINAL
	--DECLARE @SQL_SELECT_0 VARCHAR(MAX) = ''
	DECLARE @SQL_SELECT_1 VARCHAR(MAX) = ''
	DECLARE @SQL_FROM VARCHAR(MAX) = ''
	DECLARE @SQL_EXTRA VARCHAR(MAX) = ''
    DECLARE @FILTERS_OPTIONAL_PART VARCHAR(MAX) = ''
    DECLARE @FILTERS_EXCLUDING_PART VARCHAR(MAX) = ''
    DECLARE @FILTERS_FIXED_PART     VARCHAR(MAX) = ''
	
	DECLARE @Sql NVARCHAR(MAX)

	-- EL TYPE 0 INDICA QUE LAS TABLAS SE ENCUENTRAN EN UN SERVIDOR EXTERNO
	IF(@Type = 0)  
	BEGIN  
		SET @TABLE_HISTORICAL_DATA = '[' + @Ip + ']' + '.[HistoricalData].[dbo].'
		SET @TABLE_MMPRODAT = '[' + @Ip + ']' + '.[MMProDat].[dbo].'
	END
	ELSE IF(@Type = 1) 
	BEGIN
		SET @TABLE_HISTORICAL_DATA = '[HistoricalData].[dbo].'
		SET @TABLE_MMPRODAT = '[MMProDat].[dbo].'
	END
	
	IF(@Type = 0 OR @Type = 1)  
	BEGIN  
		-- ARMAMOS EL QUERY PARA HACER LA CONSULTA DE RESUMEN
		/*SET @SQL_SELECT_0 += '
			SET NOCOUNT ON
			SELECT COUNT(DISTINCT ID.[Id])								''totalInteractions'',
					COUNT(*)											''totalAudios'',
					SUM(ID.[AttentionTime])								''totalAttentionTime'' 
				'*/

		-- ARMAMOS EL QUERY PARA HACER LA CONSULTA DE CONTENIDO
		SET @SQL_SELECT_1 += '
			SET NOCOUNT ON
			SELECT ID.[Id] + ''_'' + CONVERT(VARCHAR(10), IMP.[Section]) + ''_'' + CONVERT(VARCHAR(10), IMP.Part)			''ID'',
					ID.[Id]																									''InteractionId'',
					IMP.[Section]																							''Section'',
					IMP.[Part]																								''Part'',
					''CALL''																								''Channel'',
					CASE WHEN ID.Direction = ''E'' THEN CID.CallerId ELSE CID.CalledId END									''Number'',
					''''																									''Gender'',
					ID.[HoldTime]																							''SilenceTime'',
					ID.[AttentionTime]																						''DurationTime'', -- ESTO SE DEBE CORREGIR
					ID.[AttentionTime]																						''AttentionTime'', -- SE AGREGO CAMPO PARA AMBOS EXISTAN
					ISNULL(CGRM.[Category1], '''')																			''Category1'',
					ISNULL(CGRM.[Category2], '''')																			''Category2'',
					ISNULL(CGRM.[Category3], '''')																			''Category3'',
					ISNULL(CGRM.[Description], '''')																		''Description'',
					ISNULL(CONVERT(VARCHAR(4), CGRM.[Code]), '''')															''DispositionCode'',
					ID.[Campaign]																							''Campaign'',
					ID.[LastAgent]																							''Agent'',
					IAD.[ActorName]																							''agentName'',
					ID.[Direction]																							''Type'',
					CONVERT(VARCHAR, ID.[StartDate], 120)																	''StartDate'',
					CONVERT(VARCHAR, ID.[EndDate], 120)																		''EndDate'',
					IMP.[Format]																							''Format'',
					CASE WHEN ID.Direction = ''E'' THEN CID.CallerId ELSE CID.CalledId END									''ContactAddress'',
					CASE WHEN ID.Direction = ''E'' THEN CID.CallerId ELSE CID.CalledId END									''ContactId'',
					ID.[ContactName]																						''ContactName'',
					RNA = ROW_NUMBER() OVER(PARTITION BY (ID.[Id] + ''_'' + CONVERT(VARCHAR(10), IMP.[Section]) + ''_'' + CONVERT(VARCHAR(10), IMP.Part)) ORDER BY ID.[Id]) -- ROW NUMBER AUDIO
				'

		-- ARMAMOS LA PARTE DE TABLAS 
		SET @SQL_FROM += '
				FROM ' + @TABLE_HISTORICAL_DATA + '[InteractionMultimediaParts] IMP (NOLOCK)
				LEFT JOIN ' + @TABLE_HISTORICAL_DATA + '[InteractionDetail] ID (NOLOCK) 
					ON ID.Id = IMP.Id
				LEFT JOIN ' + @TABLE_HISTORICAL_DATA + '[InteractionActorDetail] IAD (NOLOCK)
					ON IAD.[Id] = ID.[Id]
						AND IAD.[Section] = IMP.[Section]
						AND IAD.[Part] = IMP.[Part]
				LEFT JOIN (
					SELECT VCC, CampaignID, [Order], [Code], 
									[Description], Category1, Category2, Category3 
						FROM ' + @TABLE_MMPRODAT + '[CampaignGoalResultManagement] (NOLOCK)
						WHERE VCC = ''' + @VCC + '''
				) CGRM  
					ON CGRM.VCC = ID.VirtualCC 
						AND CGRM.CampaignId = ID.Campaign 
						AND CGRM.[Description] = ID.ManagementResult
				INNER JOIN ' + @TABLE_HISTORICAL_DATA + '[CallInteractionDetail] CID (NOLOCK) 
					ON ID.Id = CID.Id 
				'

		-- ARMAMOS LA PARTE BASE DE FILTROS
		SET @FILTERS_FIXED_PART = '
				WHERE ID.[VirtualCC] = ''' + @VCC + '''
					AND ID.Id IS NOT NULL '
					
		SET @FILTERS_OPTIONAL_PART = 'AND id.[EndDate] BETWEEN ''' + (SELECT CONVERT(VARCHAR(21), @StartDate, 127)) + ''' 
					AND ''' + (SELECT CONVERT(VARCHAR(21), @EndDate, 127)) + '''
					AND IMP.[Format] IN (SELECT Value FROM [dbo].[split](''' + @Format + ''','',''))
					'

		IF (CAST(@StartHour AS TIME) <= CAST(@EndHour AS TIME)) SET @FILTERS_OPTIONAL_PART += 'AND CAST(ID.[EndDate] AS TIME) BETWEEN ''' + @StartHour + ''' AND ''' + @EndHour + ''' '
		IF (CAST(@StartHour AS TIME) > CAST(@EndHour AS TIME)) SET @FILTERS_OPTIONAL_PART += 'AND CAST(ID.[EndDate] AS TIME) NOT BETWEEN ''' + @EndHour + ''' AND ''' + @StartHour + ''' '
		
		IF(@Campaign IS NOT NULL AND @Campaign <> '') SET @FILTERS_OPTIONAL_PART += 'AND ID.[Campaign] IN (SELECT Value FROM [dbo].[split](''' + @Campaign + ''','','')) '

		IF(@Agent IS NOT NULL AND @Agent <> '') SET @FILTERS_OPTIONAL_PART += 'AND ID.[FirstAgent] IN (SELECT Value FROM [dbo].[split](''' + @Agent + ''','','')) '

		IF(@Origin IS NOT NULL AND @Origin <> '') SET @FILTERS_OPTIONAL_PART += 'AND ID.[Direction] IN (SELECT Value FROM [dbo].[split](''' + @Origin + ''','','')) '

		IF(@MinDuration IS NOT NULL) SET @FILTERS_OPTIONAL_PART += 'AND ID.[AttentionTime] >= ' + (SELECT CONVERT(varchar(10), @MinDuration)) + ' '

		IF(@MaxDuration IS NOT NULL) SET @FILTERS_OPTIONAL_PART += 'AND ID.[AttentionTime] <= ' + (SELECT CONVERT(varchar(10), @MaxDuration)) + ' '
		
		IF(@ContactAddress IS NOT NULL)
		BEGIN
			SET @FILTERS_OPTIONAL_PART += '
				AND ID.ContactId LIKE ''%' + @ContactAddress + '%''
			'
		END	

		IF(@ResultCode IS NOT NULL AND @ResultCode <> '') 
			SET @FILTERS_OPTIONAL_PART += 'AND (
									(CONCAT(ID.Campaign, ''_'', ISNULL(CONVERT(VARCHAR(4), CGRM.[Code]), '''')) IN (SELECT Value FROM [dbo].[split](''' + @ResultCode + ''','','')))
									OR
									(ID.[ManagementResult] IN (SELECT Value FROM [dbo].[split](''' + @ResultCode + ''','',''))) 
								) '
	   
		IF @InteractionIds IS NOT NULL AND @InteractionIds <> ''
		BEGIN
			SET @FILTERS_OPTIONAL_PART = '';
			SET @FILTERS_EXCLUDING_PART = ' AND ID.[Id] IN (SELECT Value FROM [dbo].[split](''' + @InteractionIds + ''','','')) '
		END 

		SET @SQL_EXTRA = '
			SET NOCOUNT OFF '

		-- UNIMOS LAS PARTES DEL QUERY
		--SET @SQL_SELECT_0 += @SQL_FROM + @FILTERS_FIXED_PART + @FILTERS_OPTIONAL_PART + @FILTERS_EXCLUDING_PART + @SQL_EXTRA
		SET @SQL_SELECT_1 += @SQL_FROM + @FILTERS_FIXED_PART + @FILTERS_OPTIONAL_PART + @FILTERS_EXCLUDING_PART + @SQL_EXTRA

		-- VERIFICAMOS SI EXISTE LA TABLA TEMPORAL #TMP_HD_INTERACTIONS
		IF OBJECT_ID('TEMPDB..#TMP_HD_INTERACTIONS') IS NULL
		BEGIN
			-- CREAMOS UNA TABLA TEMPORAL PARA INSERTAR LOS REGISTROS DE LA HDI6
			CREATE TABLE #TMP_HD_INTERACTIONS
			(
				[ID] VARCHAR(150),
				[InteractionId] VARCHAR(100),
				[Section] INT,
				[Part] INT,
				[Channel] VARCHAR(50),
				[Number] VARCHAR(100),
				[Gender] VARCHAR(50),
				[SilenceTime] INT,
				[DurationTime] INT,
				[AttentionTime] INT,
				[Category1] VARCHAR(100),
				[Category2] VARCHAR(100),
				[Category3] VARCHAR(100),
				[Description] VARCHAR(150),
				[DispositionCode] INT,
				[Campaign] VARCHAR(150),
				[Agent] VARCHAR(100),
				[AgentName] VARCHAR(100),
				[Type] VARCHAR(100),
				[StartDate] VARCHAR(100),
				[EndDate] VARCHAR(100),
				[Format] VARCHAR(50),
				[ContactAddress] VARCHAR(300),
				[ContactId]  VARCHAR(50),
				[ContactName] VARCHAR(300),
				[RNA] INT
			)

			-- REAFIRMAMOS QUE EL SP NO ESTA ANIDADO EN OTRO
			SET @IS_NESTED = 0
		END
		ELSE
		BEGIN
			-- SI LA TABLA TEMPORAL YA EXISTIA, EL SP ESTA ANIDADO EN OTRO (P.E.: [dbo].[GetAsyncBillingInteractions])
			SET @IS_NESTED = 1
		END 
		
		-- EJECUTAMOS EL QUERY Y DEPOSITAMOS EL RESULTADO EN UNA TABLA TEMPORAL
		INSERT INTO #TMP_HD_INTERACTIONS
			-- EJECUTAMOS LA CONSULTA
			EXEC (@SQL_SELECT_1)

		-- VARIABLES PARA TRABAJAR CON LA TABLA TEMPORAL AL FINAL DEL SP
		DECLARE @QUERY_SUMMARY VARCHAR(MAX) = ''
		DECLARE @QUERY_DETAIL VARCHAR(MAX) = ''
		DECLARE @QUERY VARCHAR(MAX) = ''
		DECLARE @QUERY_FILTER VARCHAR(MAX) = ''
		DECLARE @QUERY_JOIN VARCHAR(MAX) = ''
	
		-- FILTRO POR INTERACCIONES EVALUADAS O NO
		IF(@Evaluated IS NOT NULL AND @Evaluated <> '')
		BEGIN 
			DECLARE @EvaluatedTable TABLE (Val BIT)
			INSERT INTO @EvaluatedTable SELECT Value FROM [dbo].[split]( @Evaluated ,',')
			-- SOLAMENTE SI ES SI O NO
			IF((SELECT COUNT(Val) FROM @EvaluatedTable) = 1 )
			BEGIN
				IF((SELECT Val FROM @EvaluatedTable WHERE Val = 1) IS NOT NULL) -- Si  es Si
				BEGIN 
					SET @QUERY_JOIN = ' JOIN [dbo].[AuditorEvaluationPlan] AEP (NOLOCK) ON (AEP.[IdInteraction] = HDI.[InteractionId] AND AEP.[Completed] = 1) '
				END
				ELSE  --Si es No
				BEGIN
					SET @QUERY_JOIN += ' LEFT JOIN [dbo].[AuditorEvaluationPlan] AEP (NOLOCK) ON (AEP.[IdInteraction] = HDI.[InteractionId] AND AEP.[Completed] = 1) '
					SET @QUERY_FILTER = ' AND AEP.[IdInteraction] IS NULL '
				END
			END
		END
		-- FIN FILTRO INTERACCIONES EVALUADAS

		-- SI EL SP NO ESTA ANIDADO, HACEMOS SELECT AL RESULTADO A MOSTRAR
		IF @IS_NESTED = 0
		BEGIN
			-- EN AMBOS CASOS SE REQUIERE EL RESUMEN
			SET @QUERY_SUMMARY = '
				SELECT HDI.[channel]										AS ''interactionType'',
						COUNT(DISTINCT (HDI.[InteractionId]))				AS ''interactions'',
						COUNT(DISTINCT (HDI.[ID]))							AS ''details'',
						SUM(HDI.[AttentionTime])							AS ''attentionTime''
					FROM #TMP_HD_INTERACTIONS HDI '
			SET @QUERY +=  @QUERY_SUMMARY + @QUERY_JOIN
			SET @QUERY += ' WHERE HDI.[RNA] = 1 ' + @QUERY_FILTER + ' GROUP BY HDI.[channel] '

			-- HACEMOS EL SELECT SEGUN EL TIPO DE BUSQUEDA SETTEADO
			--IF @ResultType = 'SUMMARIZED'
			--BEGIN
			-- END
			-- ELSE 
			IF @ResultType = 'DETAILED'
			BEGIN
				SET @QUERY_DETAIL = '
					SELECT HDI.* 
						FROM #TMP_HD_INTERACTIONS HDI ' 
				SET @QUERY += @QUERY_DETAIL + @QUERY_JOIN 
				SET @QUERY += ' WHERE HDI.[RNA] = 1 ' + @QUERY_FILTER + ' '
			END

			-- EJECUTAMOS LA CONSULTA
			EXEC (@QUERY)
    
			-- ELIMINAMOS LA TABLA TEMPORARL
			DROP TABLE #TMP_HD_INTERACTIONS
		END
	END
	ELSE
	BEGIN
		SET @Sql = 'SELECT 1 AS ''result'''		
		EXEC (@Sql)
	END

END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
