SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetBatchScheduleExecutionsByBatchType] (
	@VCC VARCHAR(50) = NULL, 
	@BatchScheduleId VARCHAR(50) = NULL,
	@BatchType VARCHAR(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	-- SI NO RECIBIMOS EL TIPO, LOS CONSULTAMOS A LA TABLA DE AGENDAS
	IF @BatchType IS NULL
		SELECT @BatchType  = BS.[BatchType] 
			FROM [dbo].[BatchSchedule] BS (NOLOCK)
			WHERE BS.[VCC] = @VCC 
				AND BS.[Id] = @BatchScheduleId

	-- EJECUTAMOS LA CONSULTA SEGUN EL TIPO DE BATCH
	IF @BatchType = 'TRANSCRIPTION'
	BEGIN
		-- HACEMOS LA CONSULTA DE BATCHES CORRESPONDIENTES A LA AGENDA
		SELECT BSE.[VCC]										'vcc',
					BSE.[Id]									'id', 
					BSE.[BatchScheduleId]						'batchScheduleId', 
					BSE.[BatchId]								'batchId', 
					BSE.[ProcessId]								'processId',
					BSE.[ExecutionDate]							'executionDate', 
					BS.[ExecutionDelay]							'executionDelay',
					BSE.[Order]									'order', 
					BSE.[Status]								'status', 
					--BSE.[CreatedDate]							'createdDate',
					--BSE.[CreatedByUserId]						'createdByUserId',
					--BSE.[LastModifiedDate]						'lastModifiedDate',
					--BSE.[LastModifiedByUserId]					'lastModifiedByUserId',
					P.[Name]									'name',
					P.[Description]								'description',
					P.[ClientId]								'clientId',
					P.[Percentage]								'percentage',
					P.[StatusDescription]						'statusDescription',
					(
						CASE WHEN P.[Status] IS NULL 
							THEN 'UNKNOWN' 
							ELSE P.[Status] END
					)											'batchStatus',
					P.[StartDate]								'startDate',
					P.[EndDate]									'endDate',
					P.[MinDurationTime]							'minDurationTime',
					P.[MaxDurationTime]							'maxDurationTime',
					P.[Language]								'language',
					P.[Environment]								'environment',
					P.[CreatedDate]								'createdDate',
					P.[CreatedByUserId]							'createdByUserId',
					P.[LastModifiedDate]						'lastModifiedDate',
					P.[LastModifiedByUserId]					'lastModifiedByUserId'
			FROM [dbo].[BatchScheduleExecution] BSE (NOLOCK)
			INNER JOIN [dbo].[BatchSchedule] BS (NOLOCK)
				ON BS.[VCC] = BSE.[VCC]
					AND BS.[Id] = BSE.[BatchScheduleId]
			LEFT JOIN [dbo].[Process] P (NOLOCK)
				ON P.[VCC] = BSE.[VCC]
					AND P.[Name] = BSE.[BatchId]
			WHERE BSE.[VCC] = @VCC
				AND BSE.[BatchScheduleId] = @BatchScheduleId
				AND BSE.[Status] <> 'PENDING'
			ORDER BY BSE.[ExecutionDate] DESC
	END
	ELSE IF @BatchType = 'TEMPLATE'
	BEGIN 
		-- HACEMOS LA CONSULTA DE BATCHES CORRESPONDIENTES A LA AGENDA
		SELECT BSE.[VCC]										'vcc',
					BSE.[Id]									'id', 
					BSE.[BatchScheduleId]						'batchScheduleId', 
					BSE.[BatchId]								'batchId', 
					BS.[ProcessFiltersId]						'templateId',
					BSE.[ProcessId]								'processId',
					BSE.[ExecutionDate]							'executionDate', 
					BS.[ExecutionDelay]							'executionDelay',
					BSE.[Order]									'order', 
					BSE.[Status]								'status', 
					--BSE.[CreatedDate]							'createdDate',
					--BSE.[CreatedByUserId]						'createdByUserId',
					--BSE.[LastModifiedDate]						'lastModifiedDate',
					--BSE.[LastModifiedByUserId]					'lastModifiedByUserId',
					S.[Name]									'name',
					S.[Description]								'description',
					S.[Percentage]								'percentage',
					S.[StatusDescription]						'statusDescription',
					(
						CASE WHEN S.[Status] IS NULL 
							THEN 'UNKNOWN' 
							WHEN S.[Status] = 1
							THEN 
								'COMPLETE'
							ELSE 'IN_PROCESS'
							END
					)											'batchStatus',
					S.[CreatedDate]								'createdDate',
					S.[CreatedByUserId]							'createdByUserId',
					S.[LastModifiedDate]						'lastModifiedDate',
					S.[LastModifiedByUserId]					'lastModifiedByUserId'
			FROM [dbo].[BatchScheduleExecution] BSE (NOLOCK)
			INNER JOIN [dbo].[BatchSchedule] BS (NOLOCK)
				ON BS.[VCC] = BSE.[VCC]
					AND BS.[Id] = BSE.[BatchScheduleId]
			LEFT JOIN [dbo].[Study] S (NOLOCK)
				ON S.[VCC] = BSE.[VCC]
					AND S.[Name] = BSE.[BatchId]
			WHERE BSE.[VCC] = @VCC
				AND BSE.[BatchScheduleId] = @BatchScheduleId
				AND BSE.[Status] <> 'PENDING'
			ORDER BY BSE.[ExecutionDate] DESC
	END

	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
