SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetBatchScheduledTemplateItemResults]
(
	@VCC					VARCHAR(50) = NULL,
	@BatchScheduledId		VARCHAR(50) = NULL,
	@StartDate				DATETIME = NULL, -- FILTRO PARA LOS RESULATDOS RECIENTES
	@EndDate				DATETIME = NULL, -- FILTRO PARA LOS RESULATDOS RECIENTES
	@Category1				VARCHAR(50) = NULL,
	@Category2				VARCHAR(50) = NULL,
	@Description			VARCHAR(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	-- OBTENEMOS LOS RESULTADOS RELACIONADOS CON EL ITEM DE LA AGENDA
	;WITH CTE AS (
		SELECT --SRD.[VCC]								'vcc',
				S.[BatchScheduleId]						'batchScheduleId',
				HTT.[Description]						'description',
				SRD.[StudyId]							'studyId',
				S.[ProcessId]							'processId',
				SRD.[TranscriptionId]					'transcriptionId',
				IIF (PAI.[InteractionType] IS NULL, 
						'CALL', 
						PAI.[InteractionType]
				)										'interactionType',
				IIF (PAI.[InteractionType] IS NULL, 
						PA.[AudioId],
						PAI.[InteractionId]
				)										'id',
				PA.[Section]							'section',
				PA.[Part]								'part',
				PAI.[Campaign]							'campaign',
				PAI.[FormattedEndDate]					'folder',
				-- RN = ROW_NUMBER() OVER(PARTITION BY IIF (PAI.[InteractionType] IS NULL, PA.[AudioId], PAI.[InteractionId]), PA.[Section], PA.[Part], PAI.[Campaign], PAI.[FormattedEndDate] ORDER BY S.[CreatedDate] desc)
				RN = ROW_NUMBER() OVER(PARTITION BY SRD.[TranscriptionId] ORDER BY S.[CreatedDate] desc)
			FROM [dbo].[StudyResultSummaryDetail] SRD (NOLOCK)
			INNER JOIN [dbo].[Study] S (nolock)
				ON S.[VCC] = SRD.[VCC]
					AND S.[Name] = SRD.[StudyId]
			LEFT JOIN [dbo].[ProcessAudio] PA (NOLOCK)
				ON PA.[VCC] = SRD.[VCC] 
					AND PA.[ProcessId] = S.[ProcessId] 
					AND CONCAT(PA.[AudioId], '_', PA.[Section], '_', PA.[Part]) = SRD.[TranscriptionId]
			LEFT JOIN [dbo].[ProcessAsyncInteraction] PAI (NOLOCK)
				ON PAI.[VCC] = SRD.[VCC]
					AND PAI.[ProcessId] = S.[ProcessId]
					AND CONCAT(PAI.[InteractionType], '_', PAI.[Campaign], '_', PAI.[FormattedEndDate], '_', PAI.[InteractionId]) = SRD.[TranscriptionId]
			INNER JOIN [dbo].[HistoricTemplateTheme] HTT (NOLOCK)
				ON HTT.[VCC] = SRD.[VCC]
					AND HTT.[StudyId] = SRD.[StudyId]
					AND HTT.[ID] = SRD.[TemplateThemeId]
			WHERE S.[VCC] = @VCC
				AND S.[BatchScheduleId] = @BatchScheduledId
				AND SRD.[CreatedDate] BETWEEN @StartDate AND @EndDate
				AND (
					HTT.[Category1] = @Category1
					OR (
						HTT.[Category1] IS NULL
						AND 
						@Category1 IS NULL
					)
				)
				AND (
					HTT.[Category2] = @Category2
					OR (
						HTT.[Category2] IS NULL
						AND
						@Category2 IS NULL
					)
				)
				AND HTT.[Description] = @Description
			-- GROUP BY SRD.[VCC], SRD.[StudyId], S.[ProcessId], SRD.[TranscriptionId], PAI.[InteractionType], PA.[AudioId], PAI.[InteractionId]
			
	)
	SELECT * FROM CTE WHERE [RN] = 1 ORDER BY [TranscriptionId]

	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
