SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
-- ESTE SP RETORNA UN RESUMEN DE LA BUSQUEDA DE INTERACCIONES DE CSV CRUZANDO CON ALLEGRO PARA INDETIFICAR LOS YA TRANSCRITOS O INPROCESS SEGUN LOS FILTROS RECIBIDOS 
-- FUNCIONA IGUAL QUE LA FUNCION EN KNEX
CREATE PROCEDURE [dbo].[GetCSVBillingInteractions] (
	@VCC VARCHAR(50) = NULL,
	@SecondsPerRequest DECIMAL(18, 5),
	@StartDate DATETIME = '1980-01-01T00:00:00',
    @EndDate DATETIME = '2050-01-01T23:59:59',
	@Campaigns VARCHAR(MAX) = '',
 	@Agents VARCHAR(MAX) = '',
   	@Origins VARCHAR(100) = NULL,
	@StartHour VARCHAR(50) = NULL,
	@EndHour VARCHAR(50) = NULL,
	@MinDuration INT = 0,
    @MaxDuration INT = 100000,
    @Results VARCHAR(MAX) = NULL,
	@InteractionIds VARCHAR(MAX) = NULL
) 
AS
BEGIN
	-- SETTEAMOS VALORES MINIMOS PARA LAS HORAS DE INICIO Y FIN
	IF (@StartHour IS NOT NULL AND @StartHour = '') SET @StartHour = '00:00:00'
	IF (@EndHour IS NOT NULL AND @EndHour = '') SET @EndHour = '23:59:59'

	-- DECLARAMOS UN CADENA PARA EL QUERY FINAL
	DECLARE @SQL_SELECT_1 VARCHAR(MAX) = '';
	DECLARE @SQL_FROM VARCHAR(MAX) = '';
	DECLARE @SQL_EXTRA VARCHAR(MAX) = '';
    DECLARE @FILTERS_OPTIONAL_PART  VARCHAR(MAX) = '';
    DECLARE @FILTERS_EXCLUDING_PART VARCHAR(MAX) = '';
    DECLARE @FILTERS_FIXED_PART     VARCHAR(MAX) = '';
	
	-- DECLARAMOS VARIABLES PARA NOS NOMBRES DE LAS TABLAS
	DECLARE @INTERACTION_DETAIL_TABLE NVARCHAR(100)
	DECLARE @INTERACTION_ACTOR_DETAIL_TABLE NVARCHAR(100)
	DECLARE @INTERACTION_MULTIMEDIA_PARTS_TABLE NVARCHAR(100)
	DECLARE @CAMPAIGN_GOAL_RESULT_MANAGEMENT_TABLE NVARCHAR(100)

	-- SETTEAMOS LOS VALORES DE DURACION MINIMA Y MAXIMA A UNO VALIDO
	IF @MinDuration = @MaxDuration AND @MaxDuration = 0 SET @MaxDuration = 100000
	IF @MinDuration IS NULL SET @MinDuration = 0
	IF @MaxDuration IS NULL SET @MaxDuration = 100000

	SET @SQL_SELECT_1 += '
		SELECT DISTINCT '

	SET @SQL_SELECT_1 += '
				''CALL''																	''interactionType'',
				SUM(CASE WHEN A.[IsTranscribed] = 1 THEN 1 ELSE 0 END)						''alreadyTranscribedAudio'',
				SUM(CASE WHEN A.[IsTranscribed] = 1 THEN PCT.[DurationTime] ELSE 0 END)		''alreadyTranscribedDurationTime'',
				SUM(CASE WHEN (A.[IsProcess] = 1 
								AND A.[IsTranscribed] IS NULL 
								AND A.[IsCancel] IS NULL
								) THEN 1 ELSE 0 END)										''inProcessAudio'',
				SUM(CASE WHEN (A.[IsProcess] = 1
								AND A.[IsTranscribed] IS NULL 
								AND A.[IsCancel] IS NULL
								) THEN PCT.[DurationTime] ELSE 0 END)						''inProcessDurationTime'',
				SUM(CASE WHEN A.[IsCancel] = 1 THEN 1 ELSE 0 END)							''canceledAudio'', 
				SUM(CASE WHEN A.[IsCancel] = 1 THEN A.[DurationTime] ELSE 0 END)			''canceledDurationTime'',
				SUM(CASE WHEN (A.[IsProcess] IS NULL
								OR (A.[IsProcess] = 1 AND A.[IsCancel] = 1)
								) THEN 1 ELSE 0 END)										''notTranscribedAudio'',
				SUM(CASE WHEN (A.[IsProcess] IS NULL 
								OR (A.[IsProcess] = 1 AND A.[IsCancel] = 1)
								) THEN PCT.[DurationTime] ELSE 0 END)						''notTranscribedDurationTime'', 
				SUM(CASE WHEN A.[IsTranscribed] = 1 
							AND A.[TotalPhrases] IS NOT NULL
						THEN A.[TotalPhrases] ELSE 0 END)									''totalPhrases'',
				SUM(CASE WHEN A.[TotalPhrases] IS NULL 
						THEN (PCT.[DurationTime] / ' + (SELECT CONVERT(varchar(10), @SecondsPerRequest)) + ') ELSE 0 END)			''totalRawPhrases'' ' 
				--SUM(PCT.[DurationTime] / ' + (SELECT CONVERT(varchar(10), @SecondsPerRequest)) + ') ''averageModelResquest'' '
	
	-- ARMAMOS LA PARTE DE TABLAS 
	SET @SQL_FROM += '
			FROM [#ProcessCsvTemp] PCT
			LEFT JOIN [dbo].[Audio] A (NOLOCK)
				-- ON CONCAT(A.[ID], ''_'', A.[Section], ''_'', A.[Part]) = PCT.[ID]
				ON A.[ID] = PCT.[ID]
					AND A.[VCC] = ''' + @VCC + ''' '

	-- ARMAMOS LA PARTE DE FILTROS
	SET @FILTERS_FIXED_PART = ' WHERE PCT.[ID] IS NOT NULL ';
    SET @FILTERS_OPTIONAL_PART = ' AND PCT.[EndDate] BETWEEN ''' + (SELECT CONVERT(VARCHAR(21), @StartDate, 127)) + ''' AND ''' + (SELECT CONVERT(VARCHAR(21), @EndDate, 127)) + ''' 
				AND PCT.[DurationTime] BETWEEN ' + (SELECT CONVERT(VARCHAR(10), @MinDuration)) + ' AND ' + (SELECT CONVERT(VARCHAR(10), @MaxDuration)) + ' '
	
    -- CONTINUAMOS CON LOS DEMAS FILTROS RECIBIDOS
	IF (@Campaigns IS NOT NULL AND @Campaigns != '') 
		SET @FILTERS_OPTIONAL_PART += 'AND PCT.[Campaign] IN (SELECT Value FROM [dbo].[split](''' + @Campaigns + ''','','')) '
	
	IF (@Agents IS NOT NULL AND @Agents != '') 
		SET @FILTERS_OPTIONAL_PART += 'AND PCT.[Agent] IN (SELECT Value FROM [dbo].[split](''' + @Agents + ''','','')) '
	
	IF (@Origins IS NOT NULL AND @Origins != '') 
		SET @FILTERS_OPTIONAL_PART += 'AND PCT.[Direction] IN (SELECT Value FROM [dbo].[split](''' + @Origins + ''','','')) '
	
	IF (@Results IS NOT NULL AND @Results != '') 
		SET @FILTERS_OPTIONAL_PART += ' 
			AND (
				(CONCAT(PCT.[Campaign], ''_'', ISNULL(CONVERT(VARCHAR(4), PCT.[DispositionCode]), '''')) IN (SELECT Value FROM [dbo].[split](''' + @Results + ''','',''))) 
				OR
				(PCT.[Description] IN (SELECT Value FROM [dbo].[split](''' + @Results + ''','','')))
			) '

	-- PARA EL CASO EN QUE HORA DE INICIO Y FIN NO SEAN NULL
	IF @StartHour IS NOT NULL AND @EndHour IS NOT NULL
	BEGIN
		IF (CAST(@StartHour AS TIME) <= CAST(@EndHour AS TIME)) 
			SET @FILTERS_OPTIONAL_PART += 'AND CAST(PCT.[EndDate] AS TIME) BETWEEN ''' + @StartHour + ''' AND ''' + @EndHour + ''' '
		IF (CAST(@StartHour AS TIME) > CAST(@EndHour AS TIME)) 
			SET @FILTERS_OPTIONAL_PART += 'AND CAST(PCT.[EndDate] AS TIME) NOT BETWEEN ''' + @EndHour + ''' AND ''' + @StartHour + ''' '
	END
	-- PARA EL CASO EN QUE HORA DE INICIO NO SEA NULL Y FIN SEA NULL
	ELSE IF @StartHour IS NOT NULL AND @EndHour IS NULL
	BEGIN
		SET @FILTERS_OPTIONAL_PART += 'AND CAST(PCT.[EndDate] AS TIME) > ''' + @StartHour + ''' '
	END
	-- PARA EL CASO EN QUE HORA DE INICIO SEA NULL Y FIN NO SEA NULL
	ELSE IF @StartHour IS NULL AND @EndHour IS NOT NULL
	BEGIN
		SET @FILTERS_OPTIONAL_PART += 'AND CAST(PCT.[EndDate] AS TIME) < ''' + @EndHour + ''' '
	END

    IF (@InteractionIds IS NOT NULL AND @InteractionIds <> '')
    BEGIN
         SET @FILTERS_OPTIONAL_PART = '';
	     SET @FILTERS_EXCLUDING_PART =' AND PCT.[ID] IN (SELECT Value FROM [dbo].[split](''' + @InteractionIds + ''','','')) ';
    END

	-- ELIMINAMOS LA TABLA TEMPORAL DESPUES DE EJECUTAR EL QUERY
	SET @SQL_EXTRA += 'DROP TABLE [#ProcessCsvTemp]'
	
	-- UNIMOS LAS PARTES DEL QUERY
	SET @SQL_SELECT_1 += @SQL_FROM + @FILTERS_FIXED_PART + @FILTERS_OPTIONAL_PART + @FILTERS_EXCLUDING_PART + @SQL_EXTRA

	-- EJECUTAMOS LA CONSULTA
	EXEC (@SQL_SELECT_1)
	
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
