SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetEvaluationResults] (
	@VCC VARCHAR(50) = NULL, 
	@EvaluationPlanId VARCHAR(50) = NULL,
	@InteractionId VARCHAR(250) = NULL,
	@AuditorId VARCHAR(50) = NULL,
	@EfectivityPlanId VARCHAR(50) = NULL
) 
AS
BEGIN
	SET NOCOUNT ON

	-- SP PARA SOLICITAR LOS RESULTADOS DE LA EVALUACION DE UNA INTERACCION POR VCC, PLAN Y AUDITOR 
	IF(@EfectivityPlanId IS NULL OR @EfectivityPlanId = '' )
	BEGIN
		SELECT ER.[IdAbility]							'idAbility',
				A.[Type]								'abilityType',
				ER.[Qualification]						'qualification',
				ER.[ScoreDescription]					'scoreDescription',
				ER.[Comment]                            'comments',
				ER.[Conditional]                        'conditional',
				ER.[EvaluationDate]						'evaluationDate',
				ER.[AbilityOrder]						'abilityOrder',
				ER.[LastModifiedByUserId]				'lastModifiedByUserId',
				ER.[LastModifiedDate]					'lastModifiedDate'
			FROM [dbo].[EvaluationResult] ER (NOLOCK)
			LEFT JOIN [dbo].[Ability] A (NOLOCK) 
				ON A.[Instance] = ER.[Instance]
					AND A.[ID] = ER.[IdAbility]
			WHERE ER.[Instance] = @VCC 
				AND ER.[IdEvaluationPlan] = @EvaluationPlanId
				AND ER.[IdInteraction] = @InteractionId
				AND ER.[IdAuditor] = @AuditorId
			ORDER BY ER.[AbilityOrder] ASC
	END
	ELSE
	BEGIN
	  
		SELECT ER.[IdAbility]							'idAbility',
			A.[Type]								'abilityType',
			ER.[Qualification]						'qualification',
			ER.[ScoreDescription]					'scoreDescription',
			ER.[Comment]                            'comments',
			ER.[Conditional]                        'conditional',
			ER.[EvaluationDate]						'evaluationDate',
			ER.[AbilityOrder]						'abilityOrder',
			ER.[LastModifiedByUserId]				'lastModifiedByUserId',
			ER.[LastModifiedDate]					'lastModifiedDate',
			ERE.[EfectivityPlanId]					'efectivityPlanId',
			ERE.[Efectivity]						'efectivity',
			ERE.[EfectivityStatus]					'efectivityStatus',
			ERE.[AbilityEvaluationFormatId]			'abilityEvaluationFormatId'
			
		FROM [dbo].[EvaluationResult] ER (NOLOCK)	
		INNER JOIN [dbo].[EvaluationResultEfectivity] ERE (NOLOCK)
			ON  ER.[Instance] = 	ERE.[VCC] AND
				ER.[IdInteraction] = ERE.[InteractionId] AND	
				ER.[IdAgent] =	ERE.[AgentId] AND
				ER.[IdEvaluationPlan] =	ERE.[EvaluationPlanId] AND
				ER.[IdAbilityEvaluationFormat] = ERE.[AbilityEvaluationFormatId] AND				
				ERE.[EfectivityStatus] IN ('CREATED','DRAFT')
		LEFT JOIN [dbo].[Ability] A (NOLOCK) 
			ON A.[Instance] = ER.[Instance]
				AND A.[ID] = ER.[IdAbility]
		WHERE ER.[Instance] = @VCC 
			AND ER.[IdEvaluationPlan] = @EvaluationPlanId
			AND ER.[IdInteraction] = @InteractionId
			AND ERE.[AuditorId] = @AuditorId
			AND ERE.EfectivityPlanId = @EfectivityPlanId
		ORDER BY ER.[AbilityOrder] ASC


	END

	-- BUSCAMOS LOS RESULTADOS DE LAS TIPIFICACIONES DE 1ER NIVEL
	SELECT ET.[AbilityId]							'abilityId',
			ET.[ScoreId]							'scoreId',
			ET.[ID]									'id',
			ET.[IsChecked]							'isChecked', 
			ET.[Comment]							'comment'
		FROM [dbo].[EvaluationTipification] ET (NOLOCK)
		WHERE ET.[VCC] = @VCC 
			AND ET.[EvaluationPlanId] = @EvaluationPlanId
			AND ET.[InteractionId] = @InteractionId
			AND ET.[AuditorId] = @AuditorId

	-- BUSCAMOS LOS RESULTADOS DE LAS TIPIFICACIONES DE 2DO Y 3ER NIVEL
	SELECT ETI.[ScoreId]								'scoreId',
			ETI.[TipificationId]						'tipificationId',
			ETI.[ID]									'id',
			ETI.[IsChecked]								'isChecked'
		FROM [dbo].[EvaluationTipificationItem] ETI (NOLOCK)
		WHERE ETI.[VCC] = @VCC 
			AND ETI.[EvaluationPlanId] = @EvaluationPlanId
			AND ETI.[InteractionId] = @InteractionId
			AND ETI.[AuditorId] = @AuditorId

	-- CONSULTAMOS LOS RESULTADOS DE LOS CAMPOS PERSONALIZADOS
	EXEC [dbo].[GetEvaluationCustomFieldResultsFromAuditorEvaluationPlan] @VCC, @EvaluationPlanId, @InteractionId, @AuditorId, NULL
		
	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
