SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetEvaluationResultsByCriteria] (
	--@VCC VARCHAR(50) = NULL,
	@InteractionStartDate				DATETIME = '1980-01-01T00:00:00',
    @InteractionEndDate					DATETIME = '2050-01-01T23:59:59',
	@EvaluationPlanId					VARCHAR(50) = NULL,
	@AgentIds							VARCHAR(MAX) = NULL,
	@OKAbilities						VARCHAR(MAX) = NULL, -- SETTEAR ALL PARA "TODOS HABILIDADES CUMPLEN"
	@KOAbilities						VARCHAR(MAX) = NULL -- SETTEAR ALL PARA "TODOS HABILIDADES NO CUMPLEN"
)
AS
BEGIN
	SET NOCOUNT ON

	-- VALIDAMOS LA DATA NECESARIA
	IF @EvaluationPlanId IS NULL OR @EvaluationPlanId = '' RAISERROR('DATABASE_ERROR_OK_EVALUATION_PLAN_ID_NOT_RECEIVED', 16, 16)
	IF @OKAbilities = 'ALL'
	-- ISNULL(LEN(@OKAbilities), 0) = 0
	BEGIN
		SELECT @OKAbilities = STUFF(
					(
						SELECT DISTINCT ',' + HA.[Title] 
							FROM [dbo].[HistoricAbilityEvaluationFormat] HAEF (NOLOCK)
							INNER JOIN [dbo].[HistoricAbility] HA (NOLOCK)
								ON HA.[VCC] = HAEF.[VCC]
									AND HA.[EvaluationPlanId] = [HAEF].[EvaluationPlanId]
									AND HA.[ID] = HAEF.[IdAbility]
							WHERE [HAEF].[EvaluationPlanId] = @EvaluationPlanId
						FOR XML PATH(''), TYPE
					).value('.', 'NVARCHAR(MAX)'), 
					1, 
					1, 
					''
		)
	END
	
	IF @KOAbilities = 'ALL'
	-- IF ISNULL(LEN(@KOAbilities), 0) = 0
	BEGIN
		SELECT @KOAbilities = STUFF(
					(
						SELECT DISTINCT ',' + HA.[Title]  
							FROM [dbo].[HistoricAbilityEvaluationFormat] HAEF (NOLOCK)
							INNER JOIN [dbo].[HistoricAbility] HA (NOLOCK)
								ON HA.[VCC] = HAEF.[VCC]
									AND HA.[EvaluationPlanId] = [HAEF].[EvaluationPlanId]
									AND HA.[ID] = HAEF.[IdAbility]
							WHERE [HAEF].[EvaluationPlanId] = @EvaluationPlanId
						FOR XML PATH(''), TYPE
					).value('.', 'NVARCHAR(MAX)'), 
					1, 
					1, 
					''
		)
	END

	-- DECLARAMOS VARIABLES PARA DATA DE HABILIDADES
	DECLARE @TOTAL_ABILITIES INT = 0
	DECLARE @TOTAL_OK_ABILITIES INT = 0
	DECLARE @TOTAL_KO_ABILITIES INT = 0
	
	-- OBTENMOS LOS VALORES
	If @OKAbilities = '' SET @TOTAL_OK_ABILITIES = 0 ELSE SELECT @TOTAL_OK_ABILITIES = COUNT(Value) FROM [dbo].[split](@OKAbilities,',')
	If @KOAbilities = '' SET @TOTAL_KO_ABILITIES = 0 ELSE SELECT @TOTAL_KO_ABILITIES = COUNT(Value) FROM [dbo].[split](@KOAbilities,',')
	SET @TOTAL_ABILITIES = @TOTAL_OK_ABILITIES + @TOTAL_KO_ABILITIES

	;WITH RAW_RESULTS_CTE AS (
		SELECT ER.* 
			FROM [dbo].[EvaluationResult] ER (NOLOCK) 
			INNER JOIN [dbo].[Ability] A (NOLOCK)
				ON A.[Instance] =  ER.[Instance]
					AND A.[ID] = ER.IdAbility
			WHERE ER.[Instance] = 'bbva'
				AND ER.[IdEvaluationPlan] = @EvaluationPlanId
				AND ER.[InteractionDateFin] BETWEEN @InteractionStartDate AND @InteractionEndDate
				AND (
					(
						ISNULL(LEN(@AgentIds), 0) <> 0
						AND
						ER.[IdAgent] IN (SELECT Value FROM [dbo].[split](@AgentIds,','))
					)
					OR
					(
						ISNULL(LEN(@AgentIds), 0) = 0
					)
				)
				AND (
					(
						-- RETORNA LAS INTERACCIONES QUE TIENEN 100 EN LAS HABILIDADES OK
						ISNULL(LEN(@OKAbilities), 0) <> 0
						AND 
						A.[Title] IN (SELECT Value FROM [dbo].[split](@OKAbilities,','))
						AND 
						ER.[AbilityInnerScore] = 100
					)
					OR
					(
						ISNULL(LEN(@KOAbilities), 0) <> 0
						AND 
						A.[Title] IN (SELECT Value FROM [dbo].[split](@KOAbilities,','))
						AND 
						ER.[AbilityInnerScore] = 0
					)
				)
	),
	FILTERED_RESULTS_CTE AS (
		SELECT * ,
				RN = ROW_NUMBER() OVER(PARTITION BY [IdInteraction] ORDER BY [CreatedDate] ASC)
			FROM RAW_RESULTS_CTE
	),
	UNIQUE_RESULTS_CTE AS (
		SELECT * 
			FROM FILTERED_RESULTS_CTE WHERE [RN] >= @TOTAL_ABILITIES
	)
	SELECT UR_CTE.[IdEvaluationPlan]				'EvaluationPlanId',
			UR_CTE.[IdCampaign]						'CampaignId',
			UR_CTE.[InteractionType]				'InteractionmType',
			UR_CTE.[IdInteraction]					'InteractionId',
			UR_CTE.[IdAgent]						'AgentId',
			UR_CTE.[InteractionDateIni]				'StartDate',
			UR_CTE.[InteractionDateFin]				'EndDate',
			HA.[Title]								'Ability',
			ER.[ScoreDescription]					'AbilityResult'
		FROM UNIQUE_RESULTS_CTE UR_CTE
		INNER JOIN [dbo].[EvaluationResult] ER (NOLOCK)
			ON ER.[Instance] = UR_CTE.[Instance] 
				AND ER.[IdEvaluationPlan] = UR_CTE.[IdEvaluationPlan]
				AND ER.[IdInteraction] =  UR_CTE.[IdInteraction]
		INNER JOIN [dbo].[HistoricAbility] HA (NOLOCK)
			ON HA.[VCC] = UR_CTE.[Instance] 
				AND HA.[EvaluationPlanId] = UR_CTE.[IdEvaluationPlan]
				AND HA.[ID] = ER.[IdAbility]
	
	/*
	SELECT STUFF(
				(
					SELECT DISTINCT ',' + IdInteraction
						FROM UNIQUE_RESULTS_CTE
					FOR XML PATH(''), TYPE
				).value('.', 'NVARCHAR(MAX)'), 
				1, 
				1, 
				''
	)						'InteractionIds'
	*/
	/*
	EXEC [dbo].[GetEvaluationResultsByCriteria] 
	@EvaluationPlanId = 'plan_transferencia_2202_bbva', 
	@AgentIds = 'xp65048@gss.bbva.com,xp65024@gss.bbva.com,maria.cubas.cruz.contractor@bbva.com', 
	@OKAbilities = 'Amabilidad_empatia,Despedida_query', 
	@KOAbilities = 'Bienvenida'
	*/

	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
