SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetEvaluations] (
	@Instance Varchar(50) = NULL,
	@IdAuditor VARCHAR(MAX) = NULL,
	@IdAgent Varchar(MAX) = NULL,
   	@IdCampaign VARCHAR(MAX) = NULL,
	@IdEvaluationPlan VARCHAR(MAX) = NULL,
 	@EvaluationDateFrom VARCHAR(50) = '1980-01-01T00:00:00',
    @EvaluationDateTo VARCHAR(50) = '2050-01-01T23:59:59',
	@EvaluationHourFrom VARCHAR(50) = '00:00:00',
    @EvaluationHourTo VARCHAR(50) = '23:59:59',
	@InteractionMinDuration Int = 0,
    @InteractionMaxDuration Int = 86400,
    @InteractionOrigins Varchar(50) = NULL,
	@InteractionResults Varchar(MAX) = NULL,
	@EvaluationTypes Varchar(MAX) = NULL,
	@InteractionTags Varchar(MAX) = NULL,
	@InteractionFormats Varchar(50) = NULL,
	@InteractionCoached VARCHAR(50) = NULL,
	@InteractionIds     VARCHAR(MAX) = NULL,
	@EvaluationsLimit Int = 0,
	@ContactAddress Varchar(300) = NULL,
	@SentimentIds VARCHAR(MAX) = NULL
)
AS
BEGIN
	SET NOCOUNT ON
	 -- SENTIMIENTOS
	 DECLARE @FILTERS_SENTIMENTIDS VARCHAR(MAX)
	 DECLARE @FILTER_ANALYSIS_TYPE VARCHAR(MAX)
	 SET @FILTERS_SENTIMENTIDS = ''
	 SET @FILTER_ANALYSIS_TYPE = ''
	IF (@SentimentIds IS NOT NULL AND @SentimentIds <> '')
        BEGIN		
			
			SET @FILTERS_SENTIMENTIDS += '  AND SAR.[SentimentId] IN (SELECT Value FROM [dbo].[split](''' + @SentimentIds + ''','','')) '					
						
	    END
	 
	 IF (SELECT COUNT(*) FROM [dbo].[split](@InteractionOrigins, ',')) = 2 
	 SET  @FILTER_ANALYSIS_TYPE =  ' AND SAR.[AnalysisType] ='+''''+'general'+''''
	 IF (@InteractionOrigins = 'IN') 
	 SET  @FILTER_ANALYSIS_TYPE =  ' AND SAR.[AnalysisType] ='+''''+'client'+''''
	 IF (@InteractionOrigins = 'OUT') 
	 SET  @FILTER_ANALYSIS_TYPE =  ' AND SAR.[AnalysisType] ='+''''+'agent'+''''
	 -- FIN SENTIMIENTOS 
	
	IF (@EvaluationHourFrom = '') SET @EvaluationHourFrom = '00:00:00';
	IF (@EvaluationHourTo = '') SET @EvaluationHourTo = '23:59:59';
	
	-- SI ORIGINS TIENE DOS VALORES, IGNORAMOS EL FILTRO
	IF (SELECT COUNT(*) FROM [dbo].[split](@InteractionOrigins, ',')) = 2 SET @InteractionOrigins = ''
	
	DECLARE @SQL_SELECT_1 VARCHAR(MAX) = ''
	DECLARE @SQL_FROM VARCHAR(MAX) = ''
	DECLARE @SQL_FILTER VARCHAR(MAX) = ''
	DECLARE @SQL_EXTRA VARCHAR(MAX) = ''
	DECLARE @FILTERS_OPTIONAL_PART VARCHAR(MAX) = ''
    DECLARE @FILTERS_EXCLUDING_PART VARCHAR(MAX) = ''
    DECLARE @FILTERS_FIXED_PART     VARCHAR(MAX) = ''

	-- EMULAMOS UNA NUEVA TABLA EN BASE A INTERACTIONEVALUATIONPLAN
	SET @SQL_SELECT_1 += '
		;WITH CTE AS (
			SELECT ER.[Instance],
					ER.[IdEvaluationPlan],
					ER.[IdInteraction], 
					ER.[IdAgent],
					IEP.[AgentName],
					SAR.[SentimentId],
					RN = ROW_NUMBER() OVER(PARTITION BY IEP.[Instance], IEP.[IdEvaluationPlan], IEP.[IdInteraction] ORDER BY IEP.[CreatedDate] ASC)
				FROM [dbo].[EvaluationResult] ER (NOLOCK) 
				INNER JOIN [dbo].[EvaluationPlan] EP (NOLOCK)
					ON EP.[Instance] = ER.[Instance]
						AND EP.[Id] =  ER.[IdEvaluationPlan]
				INNER JOIN [dbo].[AuditorEvaluationPlan] AEP (NOLOCK) 
					ON (AEP.[Instance] = ER.[Instance] 
						AND AEP.[IdAuditor] = ER.[IdAuditor] 
						AND AEP.[IdInteraction] = ER.[IdInteraction] 
						AND AEP.[InteractionType] = ER.[InteractionType] 
						AND AEP.[IdEvaluationPlan] = ER.[IdEvaluationPlan]) 
				INNER JOIN [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
					ON IEP.[Instance] = ER.[Instance] 
						AND IEP.[IdEvaluationPlan] = EP.[ID]
						AND IEP.[IdInteraction] = ER.[IdInteraction]
						AND IEP.[IdAgent] = ER.[IdAgent]
				LEFT JOIN SentimentAnalysisResult SAR
					ON IEP.[Instance] = SAR.[VCC]
						AND IEP.[IdInteraction] = SAR.[InteractionId]
						AND IEP.[InteractionSection] = SAR.[InteractionSection]
						AND IEP.[InteractionPart] = SAR.[InteractionPart]
                        AND ISNULL(IEP.[InteractionDateEnd],0) = ISNULL(SAR.[EndDate],0)
                        AND SAR.[MaxScore] = 1'                         
                         + @FILTERS_SENTIMENTIDS 
						 + @FILTER_ANALYSIS_TYPE
						 + '
				WHERE ER.[Instance] = ''' + @Instance + '''
					AND ER.[EvaluationDate] BETWEEN ''' + @EvaluationDateFrom + '''AND ''' + @EvaluationDateTo + '''
					AND EP.[Status] = CASE EP.[Evaluation_Mode] WHEN ''A'' THEN 7 ELSE EP.[Status] END 
					AND AEP.[Completed] = 1
		),
		SUMMARIZED_CTE AS (
			SELECT [Instance],
					[IdEvaluationPlan],
					[IdInteraction], 
					[IdAgent],
					[AgentName],
					[SentimentId]
				FROM CTE
				WHERE RN = 1
		) '

	SET @SQL_SELECT_1 += '
		SELECT '

	SET @SQL_SELECT_1 += '
				AEP.Completed						''completed'',
				AEP.[StatusDescription]             ''statusDescription'',
				A.[ErrorMessage]                    ''errorMessage'',
    			AEP.score							''qualification'',
    			AEP.IdAuditor						''idAuditor'',
    			U.FirstName + '' '' + U.LastName	''auditorName'',
    			MAX(ER.EvaluationDate)				''evaluationDate'',
    			AEP.IdEvaluationPlan				''idEvaluationPlan'',
				EP.Description						''evaluationPlan'',
				EP.[Evaluation_Mode]				''evaluationType'',
    			AEP.idAgent							''idAgent'',
    			S_CTE.[AgentName]						''agentName'',							-- NOMBRE DEL AGENTE
				AEP.idInteraction					''idInteraction'',
				AEP.InteractionDate					''interactionDate'',
    			AEP.InteractionType					''interactionType'',
    			AEP.IdCampaign						''idCampaign'',
				E.[Type]							''environmentType'',
				IIF (
					ERV.[InteractionId] IS NULL,
					CAST(0 AS BIT),
					CAST(1 AS BIT)
				)									''review'',
				COUNT(ERC.[Id])						''commitments'',
				S_CTE.[SentimentId]						''sentimentResult'' '

	SET @SQL_FROM += '
			FROM dbo.[EvaluationResult] ER (NOLOCK) 
			INNER JOIN SUMMARIZED_CTE S_CTE (NOLOCK) 
				ON S_CTE.[Instance] = ER.[Instance]
					AND S_CTE.[IdEvaluationPlan] = ER.[IdEvaluationPlan]
					AND S_CTE.[IdInteraction] = ER.[IdInteraction] 
					AND S_CTE.[IdAgent] = ER.[IdAgent] 
			INNER JOIN [EvaluationPlan] EP (NOLOCK) 
				ON (EP.[Instance] = ER.[Instance] 
					AND EP.[ID] = ER.IdEvaluationPlan) 
			INNER JOIN [AuditorEvaluationPlan] AEP (NOLOCK) 
				ON (AEP.[Instance] = ER.[Instance] 
					AND AEP.[IdAuditor] = ER.[IdAuditor] 
					AND AEP.[IdInteraction] = ER.[IdInteraction] 
					AND AEP.[InteractionType] = ER.[InteractionType] 
					AND AEP.[IdEvaluationPlan] = ER.[IdEvaluationPlan]) 
			LEFT JOIN [dbo].[EvaluationReview] ERV (NOLOCK)
				ON ERV.[VCC] = AEP.[Instance]
					AND ERV.[EvaluationPlanId] = AEP.[IdEvaluationPlan]
					AND ERV.[InteractionId] = AEP.[IdInteraction]
			LEFT JOIN [dbo].[EvaluationReviewCommitment] ERC (NOLOCK)
				ON ERC.[VCC] = AEP.[Instance] 
					AND ERC.[EvaluationPlanId] = AEP.[IdEvaluationPlan]
					AND ERC.[InteractionId] = AEP.[IdInteraction]
					-- AND ERC.[SupervisorId] = AEP.[IdAuditor] 
					AND ERC.[AgentId] = AEP.[idAgent]
			LEFT JOIN [dbo].[Audio] A (NOLOCK)
			    ON A.[VCC] = AEP.[Instance]
			        AND A.[ID] = AEP.[IdInteraction]			
			INNER JOIN [dbo].[Environment] E (NOLOCK)
				ON E.[VCC] = ER.[Instance]
					AND E.[Name] = EP.[EnvironmentId]
			INNER JOIN [User] U (NOLOCK) 
				ON (U.[VCC] = ER.[Instance] 
					AND U.ID = AEP.IdAuditor) '

	SET @FILTERS_FIXED_PART = '
			WHERE ER.[Instance] = ''' + @Instance + '''
				AND EP.[Status] = CASE EP.[Evaluation_Mode] WHEN ''A'' THEN 7 ELSE EP.[Status] END 
				AND AEP.[Completed] = 1 ' -- LINEA PARA FILTRAR EVALUACIONES COMPLETADAS
	SET @FILTERS_OPTIONAL_PART += '
				AND ER.[EvaluationDate] BETWEEN ''' + (SELECT CONVERT(VARCHAR(21), @EvaluationDateFrom, 127)) + ''' AND ''' + (SELECT CONVERT(VARCHAR(21), @EvaluationDateTo, 127)) + ''' '

	IF (@IdAuditor IS NOT NULL AND @IdAuditor != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[IdAuditor] IN (SELECT Value FROM [dbo].[split](''' + @IdAuditor + ''','','')) '
	IF (@IdAgent IS NOT NULL AND @IdAgent != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[IdAgent] IN (SELECT Value FROM [dbo].[split](''' + @IdAgent + ''','','')) '
	IF (@IdCampaign IS NOT NULL AND @IdCampaign != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[IdCampaign] IN (SELECT Value FROM [dbo].[split](''' + @IdCampaign + ''','','')) '
	IF (@IdEvaluationPlan IS NOT NULL AND @IdEvaluationPlan != '') SET @FILTERS_OPTIONAL_PART += 'AND EP.[ID] IN (SELECT Value FROM [dbo].[split](''' + @IdEvaluationPlan + ''','','')) '
	IF (CAST(@EvaluationHourFrom AS TIME) <= CAST(@EvaluationHourTo AS TIME)) SET @FILTERS_OPTIONAL_PART += 'AND CAST(ER.[EvaluationDate] AS TIME) BETWEEN ''' + @EvaluationHourFrom + ''' AND ''' + @EvaluationHourTo + ''' '
	IF (CAST(@EvaluationHourFrom AS TIME) > CAST(@EvaluationHourTo AS TIME)) SET @FILTERS_OPTIONAL_PART += 'AND CAST(ER.[EvaluationDate] AS TIME) NOT BETWEEN ''' + @EvaluationHourTo + ''' AND ''' + @EvaluationHourFrom + ''' '
	IF (@InteractionMinDuration IS NOT NULL) SET @FILTERS_OPTIONAL_PART += 'AND AEP.[InteractionDuration] >= ' + (SELECT CONVERT(varchar(10), @InteractionMinDuration)) + ' '
	IF (@InteractionMaxDuration IS NOT NULL) SET @FILTERS_OPTIONAL_PART += 'AND AEP.[InteractionDuration] <= ' + (SELECT CONVERT(varchar(10), @InteractionMaxDuration))+ ' '
	IF (@InteractionOrigins IS NOT NULL AND @InteractionOrigins != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[InteractionOrigin] IN (SELECT Value FROM [dbo].[split](''' + @InteractionOrigins + ''','','')) '
	--IF (@InteractionResults IS NOT NULL AND @InteractionResults != '') SET @FILTERS_OPTIONAL_PART += 'AND CONCAT(AEP.[IdCampaign], ''_'', AEP.[ManagementResult]) IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')) '
	IF (@InteractionResults IS NOT NULL AND @InteractionResults != '') 
		SET @FILTERS_OPTIONAL_PART += 'AND (
								(CONCAT(AEP.[IdCampaign], ISNULL(REPLACE(AEP.[ManagementResult], ''/'', ''_''), ''_'')) IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
								OR
								(CONCAT(AEP.[IdCampaign], ''_'', ISNULL(AEP.[ManagementResult], ''_'')) IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
								OR
								(AEP.[ManagementResult] IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
							)'
	
	IF (@EvaluationTypes IS NOT NULL AND @EvaluationTypes != '') 
	BEGIN
		SET @FILTERS_OPTIONAL_PART += '
				AND EP.[Evaluation_Mode] IN (SELECT Value FROM [dbo].[split](''' + @EvaluationTypes + ''','',''))  '
	END

	IF @ContactAddress IS NOT NULL AND @ContactAddress <> ''
	BEGIN
		SET @FILTERS_OPTIONAL_PART += '
				AND AEP.[ContactAddress] LIKE ''%' + @ContactAddress + '%'' '
	END	
	
	IF @SentimentIds IS NOT NULL AND @SentimentIds <> ''
    BEGIN            
	    SET @FILTERS_OPTIONAL_PART=' 
				AND S_CTE.[SentimentId] IN (SELECT Value FROM [dbo].[split](''' + @SentimentIds + ''','','')) '
    END
	
	IF (@InteractionTags IS NOT NULL AND @InteractionTags != '') 
	BEGIN
		SET @SQL_FROM += '
			LEFT JOIN [Tag] T (NOLOCK) 
				ON (T.[VCC] = ER.[Instance] 
					AND T.[Tag] IN (SELECT Value FROM [dbo].[split](''' + @InteractionTags + ''','',''))) '
		SET @FILTERS_OPTIONAL_PART += '
				AND T.[AudioId] LIKE CONCAT(AEP.[IdInteraction], ''%'') 
				AND T.[AudioId] IS NOT NULL '
	END
	
	--IF (@InteractionFormats IS NOT NULL AND @InteractionFormats != '') SET @FILTERS_OPTIONAL_PART += 'AND AEP.[InteractionFormat] IN (SELECT Value FROM [dbo].[split](''' + @InteractionFormats + ''','','')) '

	
	IF (@InteractionIds IS NOT NULL AND @InteractionIds <> '')
    BEGIN
        SET @FILTERS_OPTIONAL_PART = ''
	    SET @FILTERS_EXCLUDING_PART += ' AND AEP.[IdInteraction] IN (SELECT Value FROM [dbo].[split](''' + @InteractionIds + ''','','')) '
	END

	SET @SQL_EXTRA += '
			GROUP BY AEP.[Completed],
						AEP.[StatusDescription],
						A.[ErrorMessage],
						AEP.[score],
						AEP.[IdAuditor],
						U.[FirstName] + '' '' + U.[LastName],
						AEP.[IdEvaluationPlan],
						EP.[Description],
						EP.[Evaluation_Mode],
						AEP.[idAgent],
						S_CTE.[AgentName],
						AEP.[idInteraction],
						AEP.[InteractionDate],
						AEP.[InteractionType],
						AEP.[IdCampaign], 
						E.[Type],
						ERV.[InteractionId],
						S_CTE.[SentimentId]'

	IF @InteractionCoached IS NOT NULL AND @InteractionCoached != ''
	BEGIN
		IF @InteractionCoached = 'true'
			SET @SQL_EXTRA += '
				HAVING COUNT(ERC.[Id]) >= 1 '
		ELSE 
			SET @SQL_EXTRA += '
				HAVING COUNT(ERC.[Id]) = 0 '
	END

	SET @SQL_EXTRA += '
			ORDER BY MAX(ER.[EvaluationDate]) DESC '

	SET @SQL_SELECT_1 += @SQL_FROM  + @FILTERS_FIXED_PART + @FILTERS_OPTIONAL_PART + @FILTERS_EXCLUDING_PART + @SQL_EXTRA 
	--print(@SQL_SELECT_1)
	--SELECT @SQL_SELECT_1
	EXEC (@SQL_SELECT_1)
	
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
