SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
-- [dbo].[GetExecuteTemplateProcess] 'allegro', 'Quality_fullaudios_TestTemplate', NULL
CREATE PROCEDURE [dbo].[GetExecuteTemplateProcess]
(
	@VCC					VARCHAR(50),
	@StudyId				VARCHAR(200),
	@NewStructure			VARCHAR(1)
)
AS
BEGIN
	SET NOCOUNT ON

	-- Listar detalles del Study y el Proceso.
	BEGIN
		SELECT
			B.[Name]						'processName',
			A.[Name]						'studyName',
			A.[Description]					'studyDescription'
		FROM [dbo].[Study] A (NOLOCK)
		INNER JOIN Process B ON A.ProcessId = B.[Name]
		WHERE
			A.[VCC] = @VCC AND
			A.[Name] = @StudyId
	END
	BEGIN
		-- Listar datos de interacciones Tablas: Study, ProcessAudio, Audio.
		SELECT
			PA.[ProcessId]					'processId',
			PA.[AudioId]					'interactionId',
			PA.[Section]					'section',
			PA.[Part]						'part'
		FROM [dbo].[Study] S (NOLOCK)
			INNER JOIN [dbo].[ProcessAudio] PA (NOLOCK) ON S.[VCC] = PA.[VCC] AND S.[ProcessId] = PA.[ProcessId]
		WHERE
			S.[VCC] = @VCC AND
			S.[Name] = @StudyId
		
	END
	BEGIN
		-- Listar datos de la tabla StudyResultSummary.
		SELECT
			[VCC]							'vcc',
			[StudyId]						'studyId',
			[TemplateId]					'templateId',
			[TemplateThemeId]				'templateThemeId',
			[ID]							'id',
			[Description]					'description',
			[Category1]						'category1',
			[Category2]						'category2',
			[Total]							'total',
			[Duration]						'duration',
			[Silence]						'silence',
			[Confidence]					'confidence',
			[CreatedDate]					'createdDate',
			[CreatedByUserId]				'createdByUserId',
			[LastModifiedDate]				'lastModifiedDate',
			[LastModifiedByUserId]			'lastModifiedByUserId'
		FROM [dbo].[StudyResultSummary] (NOLOCK)
		WHERE
			[VCC] = @VCC AND
			[StudyId] = @StudyId
	END
	IF(@NewStructure IS NULL)
	BEGIN
		-- Listar datos de interacciones versus queries.
		SELECT
			SRSD.[TemplateThemeId]					'templateThemeId',
			SRSD.[TemplateThemeItemId]				'templateThemeItemId',
			GQ.[Query]								'query',
			PA.[AudioId]							'transcriptionId',
			PA.[Section]							'section',
			PA.[Part]								'part',
			A.[Agent]								'agent'
		FROM 
			[dbo].[Study] S (NOLOCK)
			INNER JOIN [dbo].[ProcessAudio] PA (NOLOCK) ON S.[VCC] = PA.[VCC] AND S.[ProcessId] = PA.[ProcessId]
			INNER JOIN [dbo].[Audio] A (NOLOCK) ON PA.[VCC] = A.[VCC] AND CONCAT(PA.[AudioId], '_', PA.[Section], '_', PA.[Part]) = CONCAT(A.[ID], '_', A.[Section], '_', A.[Part])
			INNER JOIN [dbo].[StudyResultSummaryDetail] SRSD (NOLOCK) ON PA.[VCC] = SRSD.[VCC] AND S.[Name] = SRSD.StudyId AND SRSD.[TranscriptionId] = CONCAT(PA.[AudioId], '_', PA.[Section], '_', PA.[Part])
			INNER JOIN [dbo].[GenericQuery] GQ (NOLOCK) ON SRSD.[VCC] = GQ.[VCC] AND SRSD.[TemplateThemeItemId] = GQ.[Name]
		WHERE
			S.[VCC] IN ('system', @VCC) AND
			S.[Name] = @StudyId
	END
	ELSE
	BEGIN
		-- Listar datos de interacciones versus queries. Parametro NewStructure.
		SELECT
			A.[TemplateThemeId]				'templateThemeId',
			A.[TemplateThemeItemId]			'templateThemeItemId',
			D.[Query]						'query',
			A.[TranscriptionId]				'transcriptionId',
			C.[Section]						'section',
			C.[Part]						'part',
			ISNULL(C.[Agent], '')			'agent'
		FROM 
			[dbo].[StudyResultSummaryDetail] A (NOLOCK)
			INNER JOIN [dbo].[Study] S (NOLOCK) ON S.[VCC] = A.[VCC] AND S.[Name] = A.[StudyId]
			INNER JOIN [dbo].[TemplateThemeItem] B (NOLOCK) ON S.[TemplateId] = B.[TemplateId] AND A.[TemplateThemeId] = B.[TemplateThemeId] AND A.[TemplateThemeItemId] = B.[ID]
			LEFT JOIN [dbo].[Audio] C (NOLOCK) ON A.[TranscriptionId] = CONCAT(C.[ID], '_', C.[Section], '_', C.[Part])
			INNER JOIN [dbo].[ProcessAudio] PA (NOLOCK) ON S.[VCC] = PA.[VCC] AND S.[ProcessId] = PA.[ProcessId] AND A.[TranscriptionId] = CONCAT(PA.[AudioId], '_', PA.[Section], '_', PA.[Part])
			INNER JOIN [dbo].[GenericQuery] D (NOLOCK) ON B.[VCC] = D.[VCC] AND  B.[ID] = D.[Name]
		WHERE
			B.[VCC] IN ('system', @VCC) AND
			A.[StudyId] = @StudyId
	END
	
	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
