SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetInteractionsByType] (
	@Instance VARCHAR(50) = NULL,
	@InitialDate DATETIME = NULL,
	@EndDate DATETIME = NULL,
	@IdCampaign VARCHAR(MAX) = 'GetInteractionsByType',
	@IdEvaluationFormat VARCHAR(MAX) = 'GetInteractionsByType',
	@IdAgent VARCHAR(MAX) = 'GetInteractionsByType',
	@IdWorkGroup VARCHAR(MAX) = 'GetInteractionsByType',
	@IdAttentionLevel VARCHAR(MAX) = 'GetInteractionsByType',
	@IdEvaluationPlan VARCHAR(MAX) = 'GetInteractionsByType',
	@IdGroup VARCHAR(MAX) = 'GetInteractionsByType',
	@IdSubGroup VARCHAR(MAX) = 'GetInteractionsByType',
	@IdAbility VARCHAR(MAX) = 'GetInteractionsByType',
	@IdAuditor VARCHAR(MAX) = 'GetInteractionsByType'
)
AS
BEGIN
	SET NOCOUNT ON;

	WITH 
		-- DECLARAMOS UNA CTE PARA DEPOSITAR LOS RESULTADOS DE LA PRIMERA CONSULTA PARA TOTAL DE EVALUACIONES Y TOTAL DE EVALUACIONES APROBADAS
		CteEvaluationResultSummary AS (
			SELECT 
					ER.IdCampaign,
					ER.IdInteraction,
					ER.IdAgent,
					ER.MinQualificationAcceptable,
					SUM(ER.Qualification) Qualification,
					AEP.Score Score, 
					ER.IdEvaluator,
					ER.IdEvaluationPlan,
					ER.InteractionType
				FROM
					[EvaluationResult] ER
				LEFT JOIN [AuditorEvaluationPlan] AEP
					ON AEP.[Instance] = ER.[Instance]
						AND AEP.[Instance] = ER.[Instance]
						AND AEP.[IdEvaluationPlan] = ER.[IdEvaluationPlan]
						AND AEP.[IdInteraction] = ER.[IdInteraction]
						AND AEP.[IdAuditor] = ER.[IdAuditor]
				WHERE
					ER.Instance = @Instance
					AND ER.EvaluationDate BETWEEN @InitialDate AND @EndDate
					AND CASE WHEN @IdAgent = 'GetInteractionsByType' THEN 'GetInteractionsByType' ELSE ER.IdAgent END IN (SELECT Value FROM [dbo].[split](@IdAgent,','))
					AND CASE WHEN @IdCampaign = 'GetInteractionsByType' THEN 'GetInteractionsByType' ELSE ER.IdCampaign END IN (SELECT Value FROM [dbo].[split](@IdCampaign,','))
					AND CASE WHEN @IdEvaluationFormat = 'GetInteractionsByType' THEN 'GetInteractionsByType' ELSE ER.IdEvaluationFormat END IN (SELECT Value FROM [dbo].[split](@IdEvaluationFormat,','))
					AND CASE WHEN @IdEvaluationPlan = 'GetInteractionsByType' THEN 'GetInteractionsByType' ELSE ER.IdEvaluationPlan END IN (SELECT Value FROM [dbo].[split](@IdEvaluationPlan,','))
					AND ER.IdAuditor LIKE CASE WHEN @IdAuditor = 'GetInteractionsByType' THEN '%' ELSE 'SPEECH' END AND ER.IdAuditor <> CASE WHEN @IdAuditor = 'GetInteractionsByType' THEN 'SPEECH' ELSE 'B_I_G_C_H_E_E_S_E' END
				GROUP BY
					ER.IdCampaign,
					ER.IdInteraction,
					ER.IdAgent,
					ER.MinQualificationAcceptable,
					ER.IdEvaluator,
					ER.IdEvaluationPlan,
					ER.InteractionType,
					AEP.Score
		)

	SELECT
			EvaluationsByType.InteractionType,
			EvaluationsByType.TotalEvaluations,
			ApprovedEvaluationsByType.ApprovedEvaluations
		FROM
			(
				SELECT
					ApprovedEvaluationsByTypeAux.InteractionType,
					SUM(ApprovedEvaluationsByTypeAux.Approved) ApprovedEvaluations
				FROM
					(
						SELECT
							*,
							-- 20191205: AL EVALUAR DIRECTAMENTE SOBRE LA NOTA DE LA INTERACCION, PASAMOS POR ALTO EL CASO DE PENALIZACION EN LA EVALUACION QUE PUEDE 
							--  AFECTAR AL SUBGRUPO, GRUPO O INTERACCION; POR ESO COMPARAMOS A NIVEL DEL SCORE DE LA EVALUACION
							-- CASE WHEN EvaluationResultsGrouped.MinQualificationAcceptable <= EvaluationResultsGrouped.Qualification THEN 1 ELSE 0 END Approved
							CASE WHEN EvaluationResultsGrouped.MinQualificationAcceptable <= EvaluationResultsGrouped.Score THEN 1 ELSE 0 END Approved
						FROM 
							CteEvaluationResultSummary EvaluationResultsGrouped
					) ApprovedEvaluationsByTypeAux
				GROUP BY
					ApprovedEvaluationsByTypeAux.InteractionType
			) ApprovedEvaluationsByType
			,
			(
				SELECT
					EvaluationResultsGroupedAux.InteractionType,
					COUNT(*) TotalEvaluations
				FROM
					CteEvaluationResultSummary EvaluationResultsGroupedAux
				GROUP BY
					EvaluationResultsGroupedAux.InteractionType
			) EvaluationsByType
		WHERE
			ApprovedEvaluationsByType.InteractionType = EvaluationsByType.InteractionType

	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
