SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetInteractionsSearch] (
   	@Instance Varchar(50) = NULL,
   	@IdAgent Varchar(MAX) = NULL,
   	@IdCampaign VARCHAR(MAX) = NULL,
 	@EvaluationDateFrom VARCHAR(MAX) = '1980-01-01T00:00:00',
    @EvaluationDateTo VARCHAR(MAX) = '2050-01-01T23:59:59',
	@EvaluationHourFrom VARCHAR(MAX) = '00:00:00',
    @EvaluationHourTo VARCHAR(MAX) = '23:59:59',
	@InteractionMinDuration Int = 0,
    @InteractionMaxDuration Int = 86400,
    @InteractionOrigins Varchar(50) = NULL,
	@InteractionTags Varchar(MAX) = NULL,
	@InteractionEvaluationTypes Varchar(MAX) = NULL,
	@InteractionResults Varchar(MAX) = NULL,
	@InteractionFormats Varchar(50) = NULL,
	@InteractionsLimit Int = 0,
	@InteractionIds         VARCHAR(MAX) = NULL,
	@InteractionWithSectionPart Bit = 0
)
AS 
BEGIN 
    SET NOCOUNT ON
	IF (@EvaluationHourFrom = '') SET @EvaluationHourFrom = '00:00:00'
	IF (@EvaluationHourTo = '') SET @EvaluationHourTo = '23:59:59'
	
	DECLARE @SQL_SELECT_0 VARCHAR(MAX) = ''
	DECLARE @SQL_SELECT_1 VARCHAR(MAX) = ''
	DECLARE @SQL_FROM VARCHAR(MAX) = ''
	DECLARE @SQL_EXTRA VARCHAR(MAX) = ''
	DECLARE @FILTERS_EXCLUDING_PART VARCHAR(MAX) = ''
	DECLARE @FILTERS_OPTIONAL_PART VARCHAR(MAX) = ''

	SET @SQL_SELECT_1 += 'SELECT DISTINCT '
	IF (@InteractionsLimit > 0) SET @SQL_SELECT_1 += 'TOP(' + (SELECT CONVERT(varchar(50), @InteractionsLimit)) + ') '
	SET @SQL_SELECT_1 += '
				e.[IdInteraction]												''id'',
				e.[IdCampaign]													''idCampaign'',
   				e.[IdCampaign]													''descriptionCampaign'',
				e.[IdAgent]														''idAgent'',
				e.[IdAgent]														''descriptionAgent'',
 				FORMAT(e.[InteractionDateStart], ''yyyy-MM-ddTHH:mm:ss.000Z'')		''dateIni'',
				e.[InteractionDateEnd]											''dateFin'',
   				e.[InteractionDuration]											''interactionTime'',
   				e.[InteractionType] 											''interactionType'',
				e.[InteractionOrigin] 											''origin'',
				e.[InteractionFormat] 											''format'',
				e.[ManagementResult]											''result'' '

	IF (@InteractionWithSectionPart = 1)
	BEGIN
		SET @SQL_SELECT_0 += '
			SELECT COUNT(DISTINCT CONCAT(e.[IdInteraction], e.[InteractionSection], e.[InteractionPart])) 	''totalRecords'',
				SUM(e.[InteractionDuration])																''totalTime'', 
				SUM(CASE WHEN e.[InteractionDuration] > 60 THEN e.[InteractionDuration] ELSE 60 END)		''roundedTime'' '

		SET @SQL_SELECT_1 += ',
			e.[InteractionSection]											''section'',
			e.[InteractionPart]												''part'' '
	END
	ELSE
	BEGIN
		SET @SQL_SELECT_0 += '
			SELECT COUNT(DISTINCT e.[IdInteraction])														''totalRecords'',
				SUM(e.[InteractionDuration])																''totalTime'', 
				SUM(CASE WHEN e.[InteractionDuration] > 60 THEN e.[InteractionDuration] ELSE 60 END)		''roundedTime'' '

	END
					
	SET @SQL_FROM += 'FROM InteractionEvaluationPlan e (NOLOCK) '

	SET @FILTERS_OPTIONAL_PART += '
			WHERE e.[Instance] = ''' + @Instance + '''
				AND e.[InteractionDateStart] >= ''' + @EvaluationDateFrom + '''
   				AND e.[InteractionDateStart] <= ''' + @EvaluationDateTo + ''' '

	IF (@IdAgent IS NOT NULL AND @IdAgent != '') SET @FILTERS_OPTIONAL_PART += 'AND e.[IdAgent] IN (SELECT Value FROM [dbo].[split](''' + @IdAgent + ''','','')) '
	IF (@IdCampaign IS NOT NULL AND @IdCampaign != '') SET @FILTERS_OPTIONAL_PART += 'AND e.[IdCampaign] IN (SELECT Value FROM [dbo].[split](''' + @IdCampaign + ''','','')) '
	IF (@InteractionOrigins IS NOT NULL AND @InteractionOrigins != '') SET @FILTERS_OPTIONAL_PART += 'AND e.[InteractionOrigin] IN (SELECT Value FROM [dbo].[split](''' + @InteractionOrigins + ''','','')) '
	IF (@InteractionMinDuration IS NOT NULL) SET @FILTERS_OPTIONAL_PART += 'AND e.[InteractionDuration] >= ' + (SELECT CONVERT(varchar(10), @InteractionMinDuration)) + ' '
	IF (@InteractionMaxDuration IS NOT NULL) SET @FILTERS_OPTIONAL_PART += 'AND e.[InteractionDuration] <= ' + (SELECT CONVERT(varchar(10), @InteractionMaxDuration))+ ' '
	IF (CAST(@EvaluationHourFrom AS TIME) <= CAST(@EvaluationHourTo AS TIME)) SET @FILTERS_OPTIONAL_PART += 'AND CAST(e.[InteractionDateStart] AS TIME) BETWEEN ''' + @EvaluationHourFrom + ''' AND ''' + @EvaluationHourTo + ''' '
	IF (CAST(@EvaluationHourFrom AS TIME) > CAST(@EvaluationHourTo AS TIME)) SET @FILTERS_OPTIONAL_PART += 'AND CAST(e.[InteractionDateStart] AS TIME) NOT BETWEEN ''' + @EvaluationHourTo + ''' AND ''' + @EvaluationHourFrom + ''' '
	IF (@InteractionFormats IS NOT NULL AND @InteractionFormats != '') SET @FILTERS_OPTIONAL_PART += 'AND e.[InteractionFormat] IN (SELECT Value FROM [dbo].[split](''' + @InteractionFormats + ''','','')) '
	IF (@InteractionResults IS NOT NULL AND @InteractionResults != '') SET @FILTERS_OPTIONAL_PART += 'AND e.[ManagementResult] IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')) '
	IF (@InteractionTags IS NOT NULL AND @InteractionTags != '') 
	BEGIN
		SET @SQL_FROM += '
			LEFT JOIN [Tag] t (NOLOCK)
				ON (t.[VCC] = ''' + @Instance + '''
					AND t.[Tag] IN (SELECT Value FROM [dbo].[split](''' + @InteractionTags + ''','',''))) '
		SET @FILTERS_OPTIONAL_PART += '
				AND t.[AudioId] LIKE CONCAT(e.[IdInteraction], ''%'') 
				AND t.[AudioId] IS NOT NULL '
	END
	
	IF (@InteractionEvaluationTypes IS NOT NULL AND @InteractionEvaluationTypes != '')
	BEGIN
		SET @SQL_FROM += '
			LEFT JOIN [EvaluationPlan] ep (NOLOCK)
				ON (ep.[Instance] = ''' + @Instance + '''
					AND ep.[ID] = e.[IdEvaluationPlan]) '
		SET @FILTERS_OPTIONAL_PART += 'AND ep.[Evaluation_Mode] IN (SELECT Value FROM [dbo].[split](''' + @InteractionEvaluationTypes + ''','','')) '
	END

	IF (@InteractionIds IS NOT NULL AND @InteractionIds <> '')
    BEGIN
       SET @FILTERS_OPTIONAL_PART = ''
	   SET @FILTERS_EXCLUDING_PART = ' AND e.[IdInteraction] IN (SELECT Value FROM [dbo].[split](''' + @InteractionIds + ''','','')) '
    END
	
	SET @SQL_EXTRA += 'ORDER BY ''dateIni'' ASC;'

	SET @SQL_SELECT_0 += @SQL_FROM + @FILTERS_OPTIONAL_PART +  @FILTERS_EXCLUDING_PART
	SET @SQL_SELECT_1 += @SQL_FROM + @FILTERS_OPTIONAL_PART +  @FILTERS_EXCLUDING_PART + @SQL_EXTRA

	EXEC (@SQL_SELECT_0)
	EXEC (@SQL_SELECT_1)
	
SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
