SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[SaveBatchError] (
	@VCC VARCHAR(50) = NULL,
	@SystemService VARCHAR(50) = NULL,
	@BatchTypeId VARCHAR(50) = NULL,
	@BatchTypeName VARCHAR(50) = NULL,
	@Implementation VARCHAR(50) = NULL,
	@InteractionId VARCHAR(250) = NULL,
	@Query VARCHAR(250) = NULL,
	@ErrorFunction VARCHAR(100) = NULL,
	@ErrorMessage VARCHAR(250) = NULL,
	@ErrorDetail VARCHAR(MAX) = NULL
)
AS
BEGIN
	-- ESTE SP TIENE LA FINALIDAD DE REGISTRAR LOS ERRORES QUE PUEDEN OCURRIR DURANTE LA EJECUCION DE LAS COLAS
	SET XACT_ABORT, NOCOUNT ON

	-- INICIAMOS UN TRY PARA EL CASO CAIGA EN CATCH HAGAMOS ROLLBACK
    BEGIN TRY
		-- VALIDAMOS QUE TENEMOS LOS PARAMETROS NECESARIOS
		IF @VCC IS NULL 
			OR @SystemService IS NULL 
			OR @BatchTypeId IS NULL 
			-- LANZAMOS MENSAJE AVISANDO QUE FALTA ACCOUNTID
			RAISERROR('DATABASE_ERROR_MISSING_PARAMETERS', 16, 16)

		-- VERIFICAMOS QUE EL BATCH TYPE SEA UN TIPO CONOCIDO DEL SISTEMA
		IF @SystemService <> 'TRANSCRIPTION' AND @SystemService <> 'SEMANTIC_ANALYSIS' AND @SystemService <> 'COGNITIVE_ANALYSIS'
			-- LANZAMOS MENSAJE AVISANDO QUE HAN SOLICITADO UNA OPERACION DESCONOCIDA
			RAISERROR('DATABASE_ERROR_UNKNOWN_SYSTEM_SERVICE', 16, 16)

		-- DECLARAMOS UNA VARIABLE PARA TIPO DE BATCH CORRESPONDIENTE AL BATCHTYPEID
		DECLARE @BATCH_TYPE VARCHAR(50) = NULL

		-- IDENTIFICAMOS EL TIPO BATCH SEGUN EL BATCHTYPEID Y SERVICIO DEL SISTEMA
		IF @SystemService = 'TRANSCRIPTION'
		BEGIN
			-- VERIFICAMOS SI ES DEL TIPO PROCESS
			IF EXISTS (SELECT 1 FROM [dbo].[Process] P (NOLOCK) WHERE [VCC] = @VCC AND [Name] = @BatchTypeId)
				SET @BATCH_TYPE = 'TRANSCRIPTION'

			-- VERIFICAMOS SI ES DEL TIPO EVALUATION_PLAN
			IF EXISTS (SELECT 1 FROM [dbo].[EvaluationPlan] P (NOLOCK) WHERE [Instance] = @VCC AND [ID] = @BatchTypeId)
				SET @BATCH_TYPE = 'EVALUATION_PLAN'
		END
		ELSE IF @SystemService = 'SEMANTIC_ANALYSIS'
		BEGIN
			-- VERIFICAMOS SI ES DEL TIPO STUDY
			IF EXISTS (SELECT 1 FROM [dbo].[Study] P (NOLOCK) WHERE [VCC] = @VCC AND [Name] = @BatchTypeId)
				SET @BATCH_TYPE = 'STUDY'

			-- VERIFICAMOS SI ES DEL TIPO EVALUATION_PLAN
			IF EXISTS (SELECT 1 FROM [dbo].[EvaluationPlan] P (NOLOCK) WHERE [Instance] = @VCC AND [ID] = @BatchTypeId)
				SET @BATCH_TYPE = 'EVALUATION_PLAN'
		END
		ELSE IF @SystemService = 'COGNITIVE_ANALYSIS'
		BEGIN
			-- VERIFICAMOS SI ES DEL TIPO STUDY
			IF EXISTS (SELECT 1 FROM [dbo].[Study] P (NOLOCK) WHERE [VCC] = @VCC AND [Name] = @BatchTypeId)
				SET @BATCH_TYPE = 'STUDY'

			-- VERIFICAMOS SI ES DEL TIPO EVALUATION_PLAN
			IF EXISTS (SELECT 1 FROM [dbo].[EvaluationPlan] P (NOLOCK) WHERE [Instance] = @VCC AND [ID] = @BatchTypeId)
				SET @BATCH_TYPE = 'EVALUATION_PLAN'
		END
		
		-- VERIFICAMOS QUE EL BATCH TYPE SEA UN TIPO CONOCIDO DEL SISTEMA
		IF @BATCH_TYPE <> 'TRANSCRIPTION' AND @BATCH_TYPE <> 'STUDY' AND @BATCH_TYPE <> 'EVALUATION_PLAN'
			-- LANZAMOS MENSAJE AVISANDO QUE HAN SOLICITADO UNA OPERACION DESCONOCIDA
			RAISERROR('DATABASE_ERROR_UNKNOWN_BATCH_TYPE', 16, 16)

		-- SOLO EN CASO DE PLANES @BatchTypeId Y @BatchTypeName SON DIFERENTES
		IF @BatchTypeName IS NULL
			SELECT @BatchTypeName = EP.[Description]
				FROM [dbo].[EvaluationPlan] EP (NOLOCK)
				 WHERE [Instance] = @VCC AND [ID] = @BatchTypeId

		-- INSERTAMOS EL REGISTRO EN LA TABLA DE ERROR
		INSERT INTO [dbo].[BatchError] (
				[VCC], [BatchType], [BatchTypeId], [BatchTypeName], [Implementation],
				[InteractionId], [Query], [ErrorFunction], [ErrorMessage], [ErrorDetail],
				[CreatedDate], [TimeStamp]
			) VALUES (
				@VCC, @BATCH_TYPE, @BatchTypeId, @BatchTypeName, @Implementation,
				@InteractionId, @Query, @ErrorFunction, @ErrorMessage, @ErrorDetail,
				GETUTCDATE(), GETUTCDATE()
			)

	END TRY
    BEGIN CATCH
        --IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION

        DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
        DECLARE @Severity integer = ERROR_SEVERITY()
        DECLARE @State integer = ERROR_STATE()

        RAISERROR(@Message, @Severity, @State)
        RETURN -1
    END CATCH

	SET XACT_ABORT, NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
