SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[SaveBatchSchedule] (
	@VCC VARCHAR(50) = NULL,
	@Id VARCHAR(50) = NULL,
	@BatchType VARCHAR(50) = NULL, -- TRANSCRIPTION/STUDY(?)/EVALUATION_PLAN
	@Frequency VARCHAR(50) = NULL,
	@Weekday INT = NULL,
	@Monthday INT = NULL,
	@DaysInterval INT = NULL,
	@HoursInterval INT = NULL,
	@ExecutionHour VARCHAR(50) = NULL,
	@FirstExecutionDate DATETIME = NULL,
	@ExecutionDelay INT = NULL,
	@StartDate DATETIME = NULL,
	@EndDate DATETIME = NULL,
	@BatchData VARCHAR(MAX) = NULL,
	@ProcessFiltersId VARCHAR(50) = NULL,
	@Status VARCHAR(50) = NULL, -- CREATED/RUNNING/PAUSED/FINISHED
	@UserId VARCHAR(50) = NULL
)
AS
BEGIN
	-- ESTE SP TIENE LA FINALIDAD DE REGISTRAR LOS ERRORES QUE PUEDEN OCURRIR DURANTE LA EJECUCION DE LAS COLAS
	SET XACT_ABORT, NOCOUNT ON

	-- INICIAMOS UN TRY PARA EL CASO CAIGA EN CATCH HAGAMOS ROLLBACK
    BEGIN TRY
		-- VALIDAMOS QUE TENEMOS LOS PARAMETROS NECESARIOS
		IF @VCC IS NULL 
			OR @Id IS NULL 
			OR @Frequency IS NULL 
			OR @StartDate IS NULL 
			-- LANZAMOS MENSAJE AVISANDO QUE FALTA ACCOUNTID
			RAISERROR('DATABASE_ERROR_MISSING_PARAMETERS', 16, 16)

		--
		UPDATE [dbo].[BatchSchedule]
			SET [LastExecutionDate] = NULL,
				[Status] = ISNULL(@Status, [Status]),
				[LastModifiedDate] = GETUTCDATE(),
				[LastModifiedByUserId] = @UserId,
				[TimeStamp] = GETUTCDATE()
			WHERE [VCC] = @VCC
				AND [Id] = @Id
				AND [BatchType] = @BatchType
		
		-- SI NO SE ACTUALIZO NINGUN REGISTRO, LO INSERTAMOS
		IF @@ROWCOUNT = 0
		BEGIN
			--select * from BatchSchedule (nolock)
			-- INSERTAMOS EL REGISTRO EN LA TABLA DE ERROR
			INSERT INTO [dbo].[BatchSchedule] (
					[VCC], [Id], [BatchType], [Frequency], [Weekday],
					[Monthday], [DaysInterval], [HoursInterval], [StartDate], [EndDate],
					[FirstExecutionDate], [LastExecutionDate], [FinalExecutionDate], [ExecutionDelay], [BatchData], 
					[ProcessFiltersId], [Status], [CreatedDate], [CreatedByUserId], [TimeStamp]
				) VALUES (
					@VCC, @Id, @BatchType, @Frequency, @Weekday,
					@Monthday, @DaysInterval, @HoursInterval, @StartDate, @EndDate,
					@FirstExecutionDate, NULL, NULL, @ExecutionDelay, @BatchData, 
					@ProcessFiltersId, 'CREATED', GETUTCDATE(), @UserId, GETUTCDATE()
				)
		END

		SELECT 1 AS 'result'
    
	END TRY
    BEGIN CATCH
        --IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION

        DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
        DECLARE @Severity integer = ERROR_SEVERITY()
        DECLARE @State integer = ERROR_STATE()

        RAISERROR(@Message, @Severity, @State)
        RETURN -1
    END CATCH

	SET XACT_ABORT, NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
