SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[SaveCustomField] (
	@VCC VARCHAR(50) = NULL, 				
	@ID VARCHAR(100) = NULL,
	@Description VARCHAR(150) = NULL,					
	@Type VARCHAR(25) = NULL,
	@Label VARCHAR(50) = NULL,
	@CreatedByUserId VARCHAR(50) = NULL,
	@LastModifiedByUserId VARCHAR(50) = NULL
) AS
BEGIN
	SET XACT_ABORT, NOCOUNT ON;

	-- INICIAMOS UN TRY PARA EL CASO CAIGA EN CATCH HAGAMOS ROLLBACK
    BEGIN TRY
        
		-- INICIAMOS LA TRANSACCION
		BEGIN TRANSACTION

		-- VERIFICAMOS SI EL CUSTOMFIELD ESTA RELACIONADO A ALGUN FORMATO EN USO
		IF EXISTS (
			SELECT DISTINCT --efcf.CustomFieldId,
							EP.[ID],
							EP.[Description]
				FROM [dbo].[EvaluationFormatCustomField] EFCF (NOLOCK)
				LEFT JOIN [dbo].[EvaluationPlan] EP (NOLOCK)
					ON EP.[IdEvaluationFormat] = EFCF.[EvaluationFormatId]
				WHERE EFCF.[VCC] = @VCC 
					AND EFCF.[CustomFieldId] = @ID
					AND EP.[Instance] IS NOT NULL
		)	
			RAISERROR('DATABABASE_ERROR_CUSTOM_FIELD_ON_USE', 16, 16)

		UPDATE [CustomField]
			SET [ID] = @ID,
				[Description] = @Description,
				[Type] = @Type,
				[Label] = @Label,
				[LastModifiedDate] = GETUTCDATE(),
				[LastModifiedByUserId] = CASE WHEN @LastModifiedByUserId IS NULL THEN [LastModifiedByUserId] ELSE @LastModifiedByUserId END,
				[TimeStamp] = GETUTCDATE()
			WHERE [VCC] = @VCC
				AND [ID] = @ID

		IF @@ROWCOUNT = 0
			INSERT INTO [CustomField] (
				[VCC], 
				[ID],
				[Description], 
				[Type], 
				[Label],
				[CreatedDate],
				[CreatedByUserId],
				[TimeStamp]
			)
			VALUES (
				@VCC, 
				@ID,
				@Description, 
				@Type, 
				@Label,
				GETUTCDATE(),
				@CreatedByUserId,
				GETUTCDATE()
			)

		SELECT 1 AS 'result'

		-- COMPLETAMOS LA TRANSACCION
		COMMIT TRANSACTION

    END TRY
    BEGIN CATCH
        IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION

        DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
        DECLARE @Severity integer = ERROR_SEVERITY()
        DECLARE @State integer = ERROR_STATE()

        RAISERROR(@Message, @Severity, @State)
        RETURN -1
    END CATCH

    SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
