SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

CREATE PROCEDURE [dbo].[SaveDictionaryWordSoundLike] (
	@VCC					VARCHAR(50) = NULL,
	@DictionaryWordId		VARCHAR(50) = NULL,
	@ID						VARCHAR(50) = NULL,
	@SoundLike				VARCHAR(50) = NULL,
	@SaveUser				VARCHAR(50) = NULL
) AS
BEGIN
	SET NOCOUNT ON
	
	-- ESTE SP TIENE LA FINALIDAD DE ACTUALIZAR LOS SALDOS DE LAS CARTERAS DEL VCC
	SET XACT_ABORT, NOCOUNT ON

	-- INICIAMOS UN TRY PARA EL CASO CAIGA EN CATCH HAGAMOS ROLLBACK
    BEGIN TRY
		-- VALIDAMOS SI LA PALABRA YA EXISTE EN LA TABLA
		IF EXISTS (
			SELECT * 
				FROM [dbo].[DictionaryWordSoundLike] (NOLOCK) 
				WHERE [VCC] = @VCC 
					AND [DictionaryWordId] = @DictionaryWordId
					AND [SoundLike] = @SoundLike
		)
			RAISERROR('DATABASE_ERROR_DICTIONARY_WORD_SOUND_LIKE_ALREADY_EXISTS', 16, 16)

		-- INSERTAMOS LA NUEVA PALABRA
		INSERT INTO [dbo].[DictionaryWordSoundLike] (
				[VCC], [DictionaryWordId], [ID], [SoundLike], [CreatedDate], [CreatedByUserId], 
				[TimeStamp]
			)
			VALUES (
				@VCC, @DictionaryWordId, NEWID(), @SoundLike, GETUTCDATE(), @SaveUser,
				GETUTCDATE()
			)
		
		-- RETORNAMOS RESULTADO 1
		SELECT 1 'result'

    END TRY
    BEGIN CATCH
        IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION

        DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
        DECLARE @Severity integer = ERROR_SEVERITY()
        DECLARE @State integer = ERROR_STATE()

        RAISERROR(@Message, @Severity, @State)
        RETURN -1
    END CATCH
	
	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
