SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[SaveEvaluationResultDraftBackup] (
	@VCC VARCHAR(50) = NULL,
	@EvaluationPlanId VARCHAR(50) = NULL,
	@InteractionType VARCHAR(50) = NULL,
	@InteractionId VARCHAR(250) = NULL,
	@AuditorId VARCHAR(50) = NULL
) AS
BEGIN
	SET NOCOUNT ON
	-- EL PRESENTE SP TIENE LA FINALIDAD DE RESPALDAR LOS RESULTADOS GENERADOS EN LA PARTE AUTOMATICA DEL PLAN MIXTO

	-- INICIAMOS UN TRY PARA EL CASO CAIGA EN CATCH HAGAMOS ROLLBACK
    BEGIN TRY
        
		-- INICIAMOS LA TRANSACCION
		BEGIN TRANSACTION

		-- DECLARAMOS UNA VARIABLE PARA VERIFICAR EL TIPO DEL PLAN
		DECLARE @IS_MIXED_EVALUATION_PLAN BIT = 0

		-- VERIFICAMOS QUE EL PLAN DE EVALUACION ES DEL TIPO MIXTO
		SELECT @IS_MIXED_EVALUATION_PLAN = IIF (EP.[Evaluation_Mode] = 'X', 1, 0) 
			FROM [dbo].[EvaluationPlan] EP (NOLOCK) 
			WHERE EP.[Instance] = @VCC
				AND EP.[ID] = @EvaluationPlanId

		-- DECLARAMOS UNA VARIABLE PARA VERIFICAR SI LA AUDITORIA YA ESTA GUARDADA COMO BORRADOR
		DECLARE @EXISTS_DRAFT_DATA BIT = 0

		IF EXISTS (
			SELECT 1 
				FROM [dbo].[EvaluationResult] (NOLOCK)
				WHERE [Instance] = @VCC
					AND [IdEvaluationPlan] = @EvaluationPlanId
					AND [InteractionType] = @InteractionType
					AND [IdInteraction] = @InteractionId
					AND [IdEvaluator] = 'SPEECH'
					AND [IdAuditor] = @AuditorId + '-DRAFT'
		)
			SET @EXISTS_DRAFT_DATA = 1

		-- SI ES UN PLAN MIXTO REALIZAMOS EL RESPALDO DE RESULTADOS
		IF @IS_MIXED_EVALUATION_PLAN = 1 AND @EXISTS_DRAFT_DATA = 0
		BEGIN
			-- INSERTAMOS EL NUEVO RESULT DE RESPALDO (SE BORRARA AL CERRAR LA AUDITORIA)
			INSERT INTO [dbo].[EvaluationResult] (
				[Instance] ,[IdCampaign] ,[IdInteraction] ,[IdAgent] ,[IdEvaluationFormat]
				,[MinQualificationAcceptable] ,[IdGroup] ,[IdSubGroup] ,[IdAbility] ,[Qualification]
				,[OwnScore] ,[InheritedScore] ,[IdEvaluator] ,[IdAuditor] ,[EvaluationDate]
				,[MaxAbilityScore] ,[AbilityInnerScore] ,[IdEvaluationPlan] ,[Comment] ,[NotApplies]
				,[ScoreDescription] ,[CampaignDescription] ,[AgentDescription] ,[InteractionDateini] ,[InteractionDatefin]
				,[InteractionAddress] ,[InteractionType] ,[AbilityOrder] ,[CreatedDate] ,[CreatedByUserId]
				,[LastModifiedDate] ,[LastModifiedByUserId] ,[IdAbilityEvaluationFormat] ,[Conditional] ,[TimeStamp]
			)
				SELECT ER.[Instance] ,ER.[IdCampaign] ,ER.[IdInteraction] ,ER.[IdAgent] ,ER.[IdEvaluationFormat]
						,ER.[MinQualificationAcceptable] ,ER.[IdGroup] ,ER.[IdSubGroup] ,ER.[IdAbility] ,ER.[Qualification]
						,ER.[OwnScore] ,ER.[InheritedScore] ,ER.[IdEvaluator] ,ER.[IdAuditor] + '-DRAFT' ,ER.[EvaluationDate]
						,ER.[MaxAbilityScore] ,ER.[AbilityInnerScore] ,ER.[IdEvaluationPlan] ,ER.[Comment] ,ER.[NotApplies]
						,ER.[ScoreDescription] ,ER.[CampaignDescription] ,ER.[AgentDescription] ,ER.[InteractionDateini] ,ER.[InteractionDatefin]
						,ER.[InteractionAddress] ,ER.[InteractionType] ,ER.[AbilityOrder] ,ER.[CreatedDate] ,ER.[CreatedByUserId]
						,ER.[LastModifiedDate] ,ER.[LastModifiedByUserId] ,ER.[IdAbilityEvaluationFormat] ,ER.[Conditional] ,ER.[TimeStamp]
					FROM [dbo].[EvaluationResult] ER (NOLOCK)
					WHERE ER.[Instance] = @VCC
						AND ER.[IdEvaluationPlan] = @EvaluationPlanId
						AND ER.[InteractionType] = @InteractionType
						AND ER.[IdInteraction] = @InteractionId
						AND ER.[IdEvaluator] = 'SPEECH'
						AND ER.[IdAuditor] = @AuditorId
		END   

		SELECT 1 AS 'result'

		-- COMPLETAMOS LA TRANSACCION
		COMMIT TRANSACTION

    END TRY
    BEGIN CATCH
        IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION

        DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
        DECLARE @Severity integer = ERROR_SEVERITY()
        DECLARE @State integer = ERROR_STATE()

        RAISERROR(@Message, @Severity, @State)
        RETURN -1
    END CATCH
	
	
    SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
