SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[SaveHistoricEvaluationPlanData] (
	@VCC VARCHAR(50) = NULL,
	@EvaluationPlanId VARCHAR(50)=NULL,
	@FormatId VARCHAR(100) = NULL
) AS
BEGIN
	SET NOCOUNT ON

	-- DECLARAMOS UNA VARIABLE PARA LA MODALIDAD DEL PLAN
	DECLARE @EVALUATION_MODE VARCHAR(50) = NULL 
	SELECT @EVALUATION_MODE = [Evaluation_Mode] FROM [dbo].[EvaluationPlan] (NOLOCK) WHERE [ID] = @EvaluationPlanId

	-- REGISTRAMOS LA DATA DEL FORMATO DE EVALUACION
	INSERT INTO [dbo].[HistoricEvaluationFormat] 
		SELECT EF.[Instance],
				EF.[ID],
				EF.[Description],
				EF.[type],
				EF.[EnvironmentType],
				EF.[MinAutomaticQualification],
				EF.[MinQualificationAcceptable],
				EF.[ManagementFormURL],
				EF.[Enabled],
				EF.[templateId],
				@EvaluationPlanId
            FROM [dbo].[EvaluationFormat] EF (NOLOCK) 
            WHERE [ID] = @FormatId 
				AND [Instance] = @VCC


	-- 
	INSERT INTO [dbo].[HistoricAbilityEvaluationFormat]
		SELECT DISTINCT A.[Instance],
							A.[ID] ,
							A.[IdEvaluationFormat],
							A.[IdAbility],
							A.[IdGroup],
							A.[IdSubGroup],
							A.[Penalizes],
							A.[Score],
							A.[Order],
							A.[Conditional],
							@EvaluationPlanId
			FROM  [dbo].[AbilityEvaluationFormat] A (NOLOCK)
			JOIN [dbo].[EvaluationFormat] EF (NOLOCK)
				ON EF.[Instance] = A.[Instance] 
					AND EF.[ID] = A.[IdEvaluationFormat]
			WHERE EF.[ID] = @FormatId AND EF.[Instance] = @VCC

	--
	INSERT INTO [dbo].[HistoricEvaluationFormatCustomField]
		SELECT ECF.[VCC],
				ECF.[ID],
				ECF.[EvaluationFormatId],
				ECF.[CustomFieldId],
				ECF.[Order],
				@EvaluationPlanId
			FROM [dbo].[EvaluationFormatCustomField] ECF (NOLOCK)
			JOIN [dbo].[EvaluationFormat] EF (NOLOCK) 
				ON ECF.[VCC] = EF.[Instance] 
				AND ECF.[EvaluationFormatId] = EF.[ID]
			WHERE EF.[ID] = @FormatId AND EF.[Instance] = @VCC
			GROUP BY ECF.[VCC],
						ECF.[ID],
						ECF.[EvaluationFormatId],
						ECF.[CustomFieldId],
						ECF.[Order]

	-- 
	INSERT INTO [dbo].[HistoricCustomField]
		SELECT C.[VCC],
				 C.[ID],
				 C.[Description],
				 C.[Type],
				 C.[Label],
				 @EvaluationPlanId
			FROM [dbo].[CustomField] C (NOLOCK)
			JOIN [dbo].[EvaluationFormatCustomField] FC (NOLOCK)
				ON C.[VCC] = FC.[VCC] 
					AND C.[ID] = FC.[CustomFieldId]
			WHERE FC.[EvaluationFormatId] = @FormatId 
				AND FC.[VCC] = @VCC
			GROUP BY C.[VCC],
						C.[ID],
						C.[Description],
						C.[Type],
						C.[Label]


	--
	INSERT INTO [dbo].[HistoricCustomFieldResult]
		SELECT CR.[VCC],
				CR.[ID],
				CR.[Description],
				CR.[Order],
				CR.[CustomFieldId],
				@EvaluationPlanId
			FROM [dbo].[CustomFieldResult] CR (NOLOCK)
			JOIN [dbo].[CustomField] C (NOLOCK)
				ON CR.[VCC] = C.[VCC] 
					AND CR.[CustomFieldId] = C.[ID]
			JOIN [dbo].[EvaluationFormatCustomField] FC (NOLOCK)
				ON C.[VCC] = FC.[VCC] 
					AND C.[ID] = FC.[CustomFieldId]
			WHERE FC.[EvaluationFormatId] = @FormatId 
				AND FC.[VCC] = @VCC
			GROUP BY CR.[VCC],
						CR.[ID],
						CR.[Description],
						CR.[Order],
						CR.[CustomFieldId]
	
	
	--
	INSERT INTO [dbo].[HistoricEvaluationFormatAttachedSignature]
		SELECT AFS.[VCC],
				AFS.[Description],
				AFS.[Order],
				AFS.[EvaluationFormatId],
				@EvaluationPlanId
			FROM [dbo].[EvaluationFormatAttachedSignature] AFS (NOLOCK)
            WHERE AFS.[EvaluationFormatId] = @FormatId 
				AND AFS.[VCC] = @VCC


	--
	INSERT INTO [dbo].[HistoricCampaignEvaluationFormat]
		SELECT CEF.[Instance],
				CEF.[IdEvaluationFormat],
				CEF.[IdCampaign],
				@EvaluationPlanId
			FROM [dbo].[CampaignEvaluationFormat] CEF (NOLOCK) 
			WHERE CEF.[IdEvaluationFormat] = @FormatId 
				AND CEF.[Instance] = @VCC
			GROUP BY CEF.[Instance],
						CEF.[IdEvaluationFormat],
						CEF.[IdCampaign]


	--
	INSERT INTO [dbo].[HistoricGroup] 
		SELECT G.[Instance] ,
				G.[ID],
				G.[Description] ,
				G.[Enabled],
				@EvaluationPlanId
			FROM [dbo].[Group] G (NOLOCK)
			JOIN [dbo].[AbilityEvaluationFormat] A (NOLOCK)
				ON  A.[Instance] = G.[Instance] 
					AND A.[IdGroup] = G.[ID]
			WHERE A.[IdEvaluationFormat] = @FormatId 
				AND A.[Instance] = @VCC
			GROUP BY G.[Instance] ,
						G.[ID],
						G.[Description] ,
						G.[Enabled] 
	


	--
	INSERT INTO [dbo].[HistoricSubGroup] 
		SELECT G.[Instance] ,
				G.[ID],
				G.[Description] ,
				G.[Enabled],
				@EvaluationPlanId
			FROM [dbo].[SubGroup] G (NOLOCK)
			JOIN [dbo].[AbilityEvaluationFormat] A (NOLOCK)
				ON  A.[Instance] = G.[Instance] 
					AND A.[IdSubGroup] = G.[ID]
			WHERE A.[IdEvaluationFormat] = @FormatId 
				AND A.[Instance] = @VCC
			GROUP BY G.[Instance],
						G.[ID],
						G.[Description] ,
						G.[Enabled] 


	-- INSERTAMOS LA DATA DE LAS HABILIDADES
	INSERT INTO [dbo].[HistoricAbility] 
		SELECT A.[Instance],
				A.[ID],
				A.[Title],
				A.[Detail],
				A.[Type],
				A.[CalificationType],
				A.[Binary],
				A.[NotApply],
				A.[Distribute],
				A.[AcceptComments],
				A.[Enabled],
				A.[AnalysisType],
				A.[Query],
				A.[QueryName],
				A.[Language],
				A.[IsNegative],
				@EvaluationPlanId
			FROM [dbo].[Ability] A (NOLOCK)
			JOIN [dbo].[AbilityEvaluationFormat] AEF (NOLOCK)
				ON  A.[Instance] = AEF.[Instance] 
					AND AEF.[IdAbility] = A.[ID]
			WHERE AEF.[IdEvaluationFormat] = @FormatId 
				AND A.[Instance] = @VCC

	-- REGISTRAMOS LOS SCORES ASOCIADOS A LAS HABILIDADES DEL FORMATO DEL PLAN
	INSERT INTO [dbo].[HistoricScore] 
		SELECT DISTINCT S.[Instance], 
						S.[ID], 
						S.[IdAbility], 
						S.[Description], 
						S.[Value], 
						EP.[ID]
			FROM [dbo].[EvaluationPlan] EP (NOLOCK)
			LEFT JOIN [dbo].[AbilityEvaluationFormat] AEP (NOLOCK)
				ON AEP.[Instance] = EP.[Instance]
					AND AEP.[IdEvaluationFormat] = EP.[IdEvaluationFormat]
			LEFT JOIN [dbo].[Score] S (NOLOCK)
				ON S.[Instance] = EP.[Instance]
					AND S.[IdAbility] = AEP.[IdAbility]
			WHERE EP.[ID] = @EvaluationPlanId
				
	-- REGISTRAMOS LOS SCORE_TIPIFICATIONS ASOCIADOS A LAS HABILIDADES DEL FORMATO DEL PLAN
	INSERT INTO [dbo].[HistoricEvaluationFormatAbilityScoreTipification]
		SELECT [VCC],
				[EvaluationFormatId],
				[ScoreId],
				[ID],
				[Description],
				[Detail],
				[Order],
				GETUTCDATE(),
				NULL,
				@EvaluationPlanId
			FROM [dbo].[EvaluationFormatAbilityScoreTipification] (NOLOCK)
			WHERE [VCC] = @VCC
				AND [EvaluationFormatId] = @FormatId
				
	-- REGISTRAMOS LOS SCORE_TIPIFICATION_QUERIES ASOCIADOS A LAS HABILIDADES DEL FORMATO DEL PLAN
	INSERT INTO [dbo].[HistoricEvaluationFormatAbilityScoreTipificationQuery]
		SELECT [VCC],
				[EvaluationFormatId],
				[ScoreId],
				[TipificationId],
				[QueryId],
				[QueryContent],
				[AcceptancePercentage],
				GETUTCDATE(),
				NULL,
				@EvaluationPlanId
			FROM [dbo].[EvaluationFormatAbilityScoreTipificationQuery] (NOLOCK)
			WHERE [VCC] = @VCC
				AND [EvaluationFormatId] = @FormatId
				-- select * FROM [dbo].[EvaluationFormatAbilityScoreTipificationQuery] (NOLOCK)
	
	
	-- REGISTRAMOS TIPIFICACIONES DE 2DO Y TERCER NIVEL CUANDO EL PLAN NO ES AUTOMATIC
	IF @EVALUATION_MODE <> 'A' 
	BEGIN
		-- REGISTRAMOS LOS SCORE_TIPIFICATIONS_ITEMS ASOCIADOS A LAS HABILIDADES DEL FORMATO DEL PLAN
		INSERT INTO [dbo].[HistoricEvaluationFormatAbilityScoreTipificationItem]
			SELECT [VCC],
					[EvaluationFormatId],
					[ScoreId],
					[TipificationId],
					[ID],
					[SecondLevelItemId],
					[Description],
					[Order],
					GETUTCDATE(),
					NULL,
					@EvaluationPlanId
				FROM [dbo].[EvaluationFormatAbilityScoreTipificationItem] (NOLOCK)
				WHERE [VCC] = @VCC
					AND [EvaluationFormatId] = @FormatId
	END
				
	-- 
	INSERT INTO [dbo].[HistoricAbilityQuery]
		SELECT AQ.[ID],
				AQ.[VCC],
				AQ.[AbilityId],
				AQ.[QueryId],
				AQ.[QueryContent],
				AQ.[AcceptancePercentage],
				AQ.[Order],
				@EvaluationPlanId
			FROM [dbo].[AbilityQuery] AQ (NOLOCK)
			JOIN [dbo].[AbilityEvaluationFormat] AEF (NOLOCK)
			ON  AQ.[VCC] = AEF.[Instance] AND AEF.[IdAbility] = AQ.[AbilityId]
			WHERE AEF.[IdEvaluationFormat] = @FormatId AND AQ.[VCC] = @VCC
			GROUP BY 
				AQ.[ID],
				AQ.[VCC],
				AQ.[AbilityId],
				AQ.[QueryId],
				AQ.[QueryContent],
				AQ.[AcceptancePercentage],
				AQ.[Order]

	--
	INSERT INTO [dbo].[HistoricAbilityQueryEntity]
		SELECT AQE.[VCC],
				AQE.[AbilityQueryId],
				AQE.[EntityId],
				AQE.[EntityName],
				AQE.[AcceptancePercentage],
				AQE.[Order],
				@EvaluationPlanId
			FROM [dbo].[AbilityQueryEntity] AQE (NOLOCK)
			JOIN [dbo].[AbilityQuery] AQ (NOLOCK)
				ON AQ.[VCC] = AQE.[VCC] 
					AND AQE.[AbilityQueryId] = AQ.[ID]
			JOIN [dbo].[AbilityEvaluationFormat] AEF (NOLOCK)
				ON  AQ.[VCC] = AEF.[Instance] 
					AND AEF.[IdAbility] = AQ.[AbilityId]
			WHERE AQ.[VCC] = @VCC 
				AND AEF.[IdEvaluationFormat] = @FormatId
			GROUP BY AQE.[VCC],
						AQE.[AbilityQueryId],
						AQE.[EntityId],
						AQE.[EntityName],
						AQE.[AcceptancePercentage],
						AQE.[Order]

	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
