SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[SaveI6InteractionAudio] (
	@VCC					VARCHAR(50) = NULL,
	@InteractionId			VARCHAR(250) = NULL,
	@OldSection				INT = NULL,
	@OldPart				INT = NULL,
	@NewSection				INT = NULL,
	@NewPart				INT = NULL,
	@AgentId				VARCHAR(50) = NULL,
	@Format					VARCHAR(10) = NULL
) AS 
BEGIN
	-- ESTE SP TIENE LA FINALIDAD DE ACTUALIZAR UNA INTERACCION DE I6
	SET XACT_ABORT, NOCOUNT ON

	-- INICIAMOS UN TRY PARA EL CASO CAIGA EN CATCH HAGAMOS ROLLBACK
    BEGIN TRY

		-- INICIAMOS LA TRANSACCION
		BEGIN TRANSACTION

		-- DECLARAMOS UNA VARIABLE PARA AYUDAR A LA ACTUALIZACION
		DECLARE @NEED_I6_UPDATE BIT = 1
		DECLARE @AGENT_NAME VARCHAR(100) = NULL -- NOMBRE DEL AGENTE

		-- ASIGNAMOS EL VALOR ACTUALIZADO DEL FLAG
		SELECT @NEED_I6_UPDATE = A.[NeedI6Update]
			FROM [dbo].[Audio] A (NOLOCK)
			WHERE A.[VCC] = @VCC
				AND A.[ID] = @InteractionId
				AND A.[Section] = @OldSection
				AND A.[Part] = @OldPart

		-- EN CASO REQUIERAN ACTUALIZACION POR UNICA VEZ
		IF @NEED_I6_UPDATE = 1
		BEGIN
			-- ASIGNAMOS A LA VARIABLE EL NOMBRE DEL AGENTE
			SELECT @AGENT_NAME = A.[Name]
				FROM [dbo].[Agent] A (NOLOCK)
				WHERE A.[VCC] = @VCC
					AND A.[AgentId] = @AgentId

			-- ACTUALIZAMOS EL SECTION Y PART EN LA INTERACCION EN LA TABLA AUDIO
			UPDATE [dbo].[Audio] 
				SET [Section] = @NewSection,
					[Part] = @NewPart,
					[Agent] = @AgentId,
					[AgentName] = @AGENT_NAME,
					[Format] = @Format,
					[NeedI6Update] = 0,
					[IsProcess] = NULL
				WHERE [VCC] = @VCC
					AND [ID] = @InteractionId
					AND [Section] = @OldSection
					AND [Part] = @OldPart
					AND [NeedI6Update] = 1

			-- ACTUALIZAMOS EL SECTION Y PART EN LA INTERACCION EN LA TABLA PROCESSAUDIO
			UPDATE [dbo].[ProcessAudio]
				SET [Section] = @NewSection,
					[Part] = @NewPart
				WHERE [VCC] = @VCC
					AND [AudioId] = @InteractionId
					AND [Section] = @OldSection
					AND [Part] = @OldPart 
		END

		-- ACTUALIZAMOS EL SECTION Y PART EN LA INTERACCION EN LA TABLA INTERACTIONEVALUATIONPLAN
		UPDATE [dbo].[InteractionEvaluationPlan] 
			SET [InteractionSection] = @NewSection,
				[InteractionPart] = @NewPart,
				[IdAgent] = @AgentId,
				[AgentName] = @AGENT_NAME,
				[InteractionFormat] = @Format
			WHERE [Instance] = @VCC
				AND [IdInteraction] = @InteractionId
				AND [InteractionSection] = @OldSection
				AND [InteractionPart] = @OldPart 
			
		-- RETORNAMOS RESULTADO 1
		SELECT 1 'result'

		-- COMPLETAMOS LA TRANSACCION
		COMMIT TRANSACTION

    END TRY
    BEGIN CATCH
        IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION

        DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
        DECLARE @Severity integer = ERROR_SEVERITY()
        DECLARE @State integer = ERROR_STATE()

        RAISERROR(@Message, @Severity, @State)
        RETURN -1
    END CATCH

	SET XACT_ABORT, NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
