SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

CREATE PROCEDURE [dbo].[SaveInteractionEvaluationPlanResult] (
	@VCC VARCHAR(50),
	@IdEvaluationPlan VARCHAR(50),
	@IdAuditor VARCHAR(50),
	@IdInteraction VARCHAR(250),
	@InteractionType VARCHAR(50),
	@Score NUMERIC(5,2),
	@AutomaticScore NUMERIC(5,2),
	@ManualScore NUMERIC(5,2),
	@IsDraft BIT
) AS
BEGIN
	SET NOCOUNT ON

 	UPDATE [dbo].[AuditorEvaluationPlan] 
		SET [Completed] = IIF (@IsDraft = 1, 0, 1), 
			[Score] = @Score, 
			[AutomaticScore] = @AutomaticScore,
			[ManualScore] = @ManualScore,
			[StatusDescription] = IIF (@IsDraft = 1, 'DRAFT', 'COMPLETED'),
			[LastModifiedDate] = GETUTCDATE(),
			[TimeStamp] = GETUTCDATE()
		WHERE [Instance] = @VCC
			AND [IdEvaluationPlan] = @IdEvaluationPlan
			AND [IdInteraction] = @IdInteraction
			AND [InteractionType] = @InteractionType
			AND [IdAuditor] = @IdAuditor

	-- ACTUALIZAMOS LAS NOTAS FINALES TENIENDO EN CUENTA LAS PENALIZACIONES
	IF @IsDraft = 0
	BEGIN
		;WITH CTEFP AS (
			SELECT DISTINCT 
					ER.[Instance],
					ER.[IdInteraction],
					ER.[IdEvaluationPlan],
					ER.[IdEvaluationFormat],
					ER.[IdAbility],
					CASE WHEN ER.[Qualification] = 0 AND AEF.[Penalizes] <> 'NO' THEN 1 ELSE 0 END 'Penalized',
					AEF.[Penalizes],
					CASE AEF.[Penalizes]
						WHEN 'INT' THEN ER.[IdInteraction] 
						WHEN 'GRP' THEN ER.[IdGroup] 
						WHEN 'SGR' THEN ER.[IdSubGroup] 
					END 'PenalizedOn',
					RN = ROW_NUMBER() OVER(PARTITION BY ER.[IdInteraction], CASE WHEN ER.[Qualification] = 0 THEN 1 ELSE 0 END 
						ORDER BY CASE AEF.[Penalizes]
						WHEN 'INT' THEN 1 
						WHEN 'GRP' THEN 2 
						WHEN 'SGR' THEN 3 
					END)
				FROM [EvaluationResult] ER (NOLOCK) 
				LEFT JOIN [AbilityEvaluationFormat] AEF (NOLOCK) 
					ON AEF.[Instance] = ER.[Instance] 
						AND AEF.[IdEvaluationFormat] = ER.[IdEvaluationFormat]
						AND AEF.[IdAbility] = ER.[IdAbility]
				WHERE ER.[IdEvaluationPlan] IN (@IdEvaluationPlan) 
					AND ER.[IdInteraction] = @IdInteraction
					AND ER.[IdAuditor] = @IdAuditor
					AND ER.[Qualification] = 0 
					AND AEF.[Penalizes] <> 'NO'
				-- WHERE ER.[IdEvaluationPlan] IN (SELECT DISTINCT EPA.[EvaluationPlanId] FROM [DummyEvaluationPlanAbility] EPA (NOLOCK) WHERE EPA.[EvaluationPlanId] IS NOT NULL)
		),
		CTEFS AS (
			SELECT ER.[Instance],
					ER.[IdEvaluationPlan],
					ER.[IdInteraction],
					ER.[IdAuditor],
					SUM(ER.[Qualification])															'TOTAL_SCORE',
					SUM(IIF(HA.[Type] = 'MANUAL_AUTOMATIC', ER.[Qualification], 0))					'TOTAL_AUTOMATIC_SCORE',
					SUM(IIF(HA.[Type] = 'MANUAL', ER.[Qualification], 0))							'TOTAL_MANUAL_SCORE',
					--SUM(ER.[Qualification] * CASE WHEN FP2.[Penalized] IS NULL THEN 1 ELSE 0 END) 'PENALIZED_SCORE',
					SUM(ER.[Qualification] * (
						CASE WHEN (
							CASE FP2.[Penalizes]
								WHEN 'INT' THEN ER.[IdInteraction] 
								WHEN 'GRP' THEN ER.[IdGroup] 
								WHEN 'SGR' THEN ER.[IdSubGroup] 
							END = FP2.[PenalizedOn]
							AND FP2.[Penalized] = 1) THEN 0 ELSE 1 END
					))																				'PENALIZED_SCORE',
					SUM(IIF(HA.[Type] = 'MANUAL_AUTOMATIC',
						ER.[Qualification] * (
						CASE WHEN (
							CASE FP2.[Penalizes]
								WHEN 'INT' THEN ER.[IdInteraction] 
								WHEN 'GRP' THEN ER.[IdGroup] 
								WHEN 'SGR' THEN ER.[IdSubGroup] 
							END = FP2.[PenalizedOn]
							AND FP2.[Penalized] = 1
						) THEN 0 ELSE 1 END),
						0) 
					)																				'PENALIZED_AUTOMATIC_SCORE',
					SUM(IIF(HA.[Type] = 'MANUAL',
						ER.[Qualification] * (
						CASE WHEN (
							CASE FP2.[Penalizes]
								WHEN 'INT' THEN ER.[IdInteraction] 
								WHEN 'GRP' THEN ER.[IdGroup] 
								WHEN 'SGR' THEN ER.[IdSubGroup] 
							END = FP2.[PenalizedOn]
							AND FP2.[Penalized] = 1
						) THEN 0 ELSE 1 END),
						0) 
					)																				'PENALIZED_MANUAL_SCORE'
				FROM EvaluationResult ER (NOLOCK) 
				LEFT JOIN (
					-- HACEMOS UN CRUCE CON LA TABLA VARIABLE Y TOMAMOS SOLO UNA DE LAS PENALIZACIONES POR INTERACCION, EMPEZANDO 
					--  POR LA MAS PRIORITARIA (FP.[RN])
					SELECT DISTINCT FP.[Instance],
									FP.[IdEvaluationPlan], 
									FP.[IdInteraction], 
									FP.[Penalized],
									FP.[Penalizes], 
									FP.[PenalizedOn]
						FROM CTEFP FP (NOLOCK)
						WHERE FP.[Penalizes] <> 'NO'
							AND FP.[RN] = 1
				) FP2
					ON FP2.[Instance] = ER.[Instance]
						AND ER.[IdEvaluationPlan] = FP2.[IdEvaluationPlan]
						AND ER.[IdInteraction] = FP2.[IdInteraction]
						/*
						AND CASE FP2.[Penalizes]
								WHEN 'INT' THEN ER.[IdInteraction] 
								WHEN 'GRP' THEN ER.[IdGroup] 
								WHEN 'SGR' THEN ER.[IdSubGroup] 
							END = FP2.[PenalizedOn]
						AND FP2.[Penalized] = 1
						*/
				INNER JOIN dbo.[HistoricAbility] HA (NOLOCK)
					ON HA.[VCC] = ER.[Instance]
						AND HA.[EvaluationPlanId] = ER.[IdEvaluationPlan]
						AND HA.[ID] = ER.[IdAbility]
				--WHERE ER.[Instance] = 'multisalud'
				WHERE -- ER.[Instance] = FP2.[Instance] -- ESTA LINEA CAUSA QUE NO SE ACTUALICEN LOS SCORES LAS EVALUACIONES QUE NO PENALIZAN
					-- AND 
					ER.[IdEvaluationPlan] IN (@IdEvaluationPlan) 
					AND ER.[IdInteraction] = @IdInteraction
					AND ER.[IdAuditor] = @IdAuditor
					--AND ER.[IdEvaluationPlan] IN (SELECT DISTINCT EvaluationPlanId FROM DummyEvaluationPlanAbility)
				GROUP BY ER.[Instance],
					ER.[IdEvaluationPlan],
					ER.[IdInteraction],
					ER.[IdAuditor]
		)
		--SELECT * FROM CTEFS

		-- ACTUALIZAMOS LOS REGISTROS DE EVALUACION CON LA NOTA PENALIZADA OBTENIDA EN LOS PASOS ANTERIORES
		UPDATE AEP 
			SET AEP.[Score] = FS.[PENALIZED_SCORE],
				AEP.[AutomaticScore] = FS.[PENALIZED_AUTOMATIC_SCORE],
				AEP.[ManualScore] = FS.[PENALIZED_MANUAL_SCORE],
				AEP.[LastModifiedDate] = GETUTCDATE(),
				AEP.[TimeStamp] = GETUTCDATE()
			FROM AuditorEvaluationPlan AEP (NOLOCK)
			LEFT JOIN CTEFS FS (NOLOCK) 
				ON FS.[Instance] = AEP.[Instance] 
					AND FS.[IdEvaluationPlan] = AEP.[IdEvaluationPlan] 
					AND FS.[IdInteraction] = AEP.[IdInteraction]
					AND FS.[IdAuditor] = AEP.[IdAuditor]
			WHERE FS.[Instance] IS NOT NULL
	END

    SELECT 1 AS 'result'

 	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
